@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv;
@@ -55,7 +69,7 @@ public class DirectoryManager {
      */
     public static synchronized File getUserDirectory() {
         if (USER_DIRECTORY == null) {
-            System.out.print("Fetching user directory... ");
+            log.info("Fetching user directory... ");
             USER_DIRECTORY = FileSystemView.getFileSystemView().getDefaultDirectory();
             //Mostly for testing, in some environments USER_DIRECTORY can be null
             if (USER_DIRECTORY == null) {
@@ -104,7 +118,7 @@ public class DirectoryManager {
                     try {
                         boolean wasSuccessful = IGV_DIRECTORY.mkdir();
                         if (!wasSuccessful) {
-                            System.err.println("Failed to create user directory!");
+                            log.error("Failed to create user directory!");
                             IGV_DIRECTORY = null;
                         }
                     } catch (Exception e) {
@@ -168,8 +182,7 @@ public class DirectoryManager {
         } catch (Exception e) {
             userPrefs.remove(IGV_DIR_USERPREF);
             override = null;
-            System.err.println("Error creating user directory");
-            e.printStackTrace();
+            log.error("Error creating user directory", e);
         }
         return override;
     }
@@ -412,16 +425,21 @@ public class DirectoryManager {
     public static void initializeLog() {
 
         Logger logger = Logger.getRootLogger();
-
         PatternLayout layout = new PatternLayout();
         layout.setConversionPattern("%p [%d{ISO8601}] [%F:%L]  %m%n");
 
+        //Temp appender just used while initializing log
+        //If something goes wrong here we want a log of it
+        ConsoleAppender tempAppender = new ConsoleAppender(layout, "System.err");
+        logger.addAppender(tempAppender);
+
         // Create a log file that is ready to have text appended to it
         try {
             File logFile = getLogFile();
             RollingFileAppender appender = new RollingFileAppender();
             appender.setName("IGV_ROLLING_APPENDER");
             appender.setFile(logFile.getAbsolutePath());
+            //Will actually inherit from root logger
             appender.setThreshold(Level.ALL);
             appender.setMaxFileSize("1000KB");
             appender.setMaxBackupIndex(1);
@@ -429,13 +447,10 @@ public class DirectoryManager {
             appender.setAppend(true);
             appender.activateOptions();
             logger.addAppender(appender);
-
+            logger.removeAppender(tempAppender);
         } catch (IOException e) {
-            // Can't create log file, just log to console
-            System.err.println("Error creating log file");
-            e.printStackTrace();
-            ConsoleAppender consoleAppender = new ConsoleAppender();
-            logger.addAppender(consoleAppender);
+            // Can't create log file, just log to console as set in log4j.properties
+            log.error("Error creating log file", e);
         }
     }
 }
