@@ -1,19 +1,33 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv;
 
 import org.apache.log4j.Logger;
+import org.broad.igv.renderer.SequenceRenderer;
 
-import java.awt.*;
 import java.io.IOException;
 import java.util.*;
 import java.util.List;
@@ -25,19 +39,25 @@ import java.util.regex.Pattern;
  */
 public class Globals {
 
+    public static final int DESIGN_DPI = 96;
     private static Logger log = Logger.getLogger(Globals.class);
 
 
     /**
      * CONSTANTS
      */
-    final public static String CHR_ALL = "All";
+    public static final String CHR_ALL = "All";
+    public static final String TRACK_NAME_ATTRIBUTE = "NAME";
+    public static final String TRACK_DATA_FILE_ATTRIBUTE = "DATA FILE";
+    public static final String TRACK_DATA_TYPE_ATTRIBUTE = "DATA TYPE";
+
     private static boolean headless = false;
     private static boolean suppressMessages = false;
     private static boolean batch = false;
     private static boolean testing = false;
     public static int CONNECT_TIMEOUT = 20000;        // 20 seconds
     public static int READ_TIMEOUT = 1000 * 3 * 60;   // 3 minutes
+
     /**
      * Field description
      */
@@ -58,8 +78,13 @@ public class Globals {
     final public static String GENOME_ARCHIVE_CYTOBAND_FILE_KEY = "cytobandFile";
     final public static String GENOME_ARCHIVE_GENE_FILE_KEY = "geneFile";
     final public static String GENOME_ARCHIVE_SEQUENCE_FILE_LOCATION_KEY = "sequenceLocation";
+
+    /**
+     * Whether the sequenceLocation has been modified from the version of the .genome
+     * file on the server
+     */
+    public static final String GENOME_ARCHIVE_CUSTOM_SEQUENCE_LOCATION_KEY = "customSequenceLocation";
     public static final String GENOME_CHR_ALIAS_FILE_KEY = "chrAliasFile";
-    public static final String DEFAULT_GENOME = "hg18";
 
     // Default user folder
 
@@ -90,10 +115,9 @@ public class Globals {
             System.getProperty("os.name").toLowerCase().startsWith("linux");
 
     final public static boolean IS_JWS =
-            System.getProperty("webstart.version") != null;
+            System.getProperty("webstart.version", null) != null || System.getProperty("javawebstart.version", null) != null;
 
     public static final String JAVA_VERSION_STRING = "java.version";
-    public static Map<Character, Color> nucleotideColors;
 
     //Location of bedtools executable
     //Note: It is recommended you use an absolute path here.
@@ -102,8 +126,10 @@ public class Globals {
     //is named rather than the full path given
     public static String BEDtoolsPath = "/usr/local/bin/bedtools"; //"bedtools"
     public static boolean toolsMenuEnabled = false;
-    public static boolean production;
+    public static boolean development = false;
 
+    public static String versionURL = "http://www.broadinstitute.org/igv/projects/current/version.txt";
+    public static String downloadURL = "http://www.broadinstitute.org/igv/download";
     static {
         Properties properties = new Properties();
         try {
@@ -114,21 +140,16 @@ public class Globals {
         VERSION = properties.getProperty("version", "???");
         BUILD = properties.getProperty("build", "???");
         TIMESTAMP = properties.getProperty("timestamp", "???");
-
-        nucleotideColors = new HashMap();
-        nucleotideColors.put('A', Color.GREEN);
-        nucleotideColors.put('a', Color.GREEN);
-        nucleotideColors.put('C', Color.BLUE);
-        nucleotideColors.put('c', Color.BLUE);
-        nucleotideColors.put('T', Color.RED);
-        nucleotideColors.put('t', Color.RED);
-        nucleotideColors.put('G', new Color(209, 113, 5));
-        nucleotideColors.put('g', new Color(209, 113, 5));
-        nucleotideColors.put('N', Color.gray.brighter());
-        nucleotideColors.put('n', Color.gray.brighter());
-
         BEDtoolsPath = System.getProperty("BEDtoolsPath", BEDtoolsPath);
-        production = Boolean.parseBoolean(System.getProperty("production", "false"));
+
+         //Runtime property overrides compile-time property, if both exist.
+        //If neither exist we default to false
+        final String developmentProperty = System.getProperty("development", properties.getProperty("development", "false"));
+        development = Boolean.parseBoolean(developmentProperty);
+        if(development){
+            log.warn("Development mode is enabled");
+        }
+
     }
 
     public static void setHeadless(boolean bool) {
@@ -163,8 +184,8 @@ public class Globals {
         return "<html>Version " + VERSION + " (" + BUILD + ")<br>" + TIMESTAMP;
     }
 
-    public static boolean isProduction() {
-         return production;
+    public static boolean isDevelopment() {
+        return development;
     }
 
 
@@ -181,14 +202,23 @@ public class Globals {
      * Checks whether the current JVM is the minimum specified version
      * or higher. Only compares up to as many characters as
      * in {@code minVersion}
+     *
      * @param minVersion
      * @return
      */
-    public static boolean isVersionOrHigher(String minVersion){
+    public static boolean checkJavaVersion(String minVersion) {
         String curVersion = System.getProperty(JAVA_VERSION_STRING);
-        if(curVersion.length() >= minVersion.length()){
+        if (curVersion.length() >= minVersion.length()) {
             curVersion = curVersion.substring(0, minVersion.length());
         }
         return curVersion.compareTo(minVersion) >= 0;
     }
+
+    /**
+     * Return the URL to fetch the current IGV version (note:  not Java version)
+     * @return
+     */
+    public static String getVersionURL() {
+        return versionURL;
+    }
 }
