@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.cli_plugin;
@@ -24,10 +38,11 @@ import org.broad.igv.track.FeatureTrack;
 import org.broad.igv.track.Track;
 import org.broad.igv.util.FileUtils;
 import org.broad.igv.util.RuntimeUtils;
-import org.broad.tribble.AsciiFeatureCodec;
-import org.broad.tribble.Feature;
-import org.broad.tribble.FeatureCodec;
-import org.broad.tribble.bed.SimpleBEDFeature;
+import htsjdk.tribble.AsciiFeatureCodec;
+import htsjdk.tribble.Feature;
+import htsjdk.tribble.FeatureCodec;
+import htsjdk.tribble.bed.SimpleBEDFeature;
+import htsjdk.tribble.readers.PositionalBufferedStream;
 
 import javax.xml.bind.annotation.*;
 import javax.xml.bind.annotation.adapters.XmlAdapter;
@@ -304,7 +319,7 @@ public abstract class PluginSource<E extends Feature, D extends Feature> {
 
     protected List<Alignment> getAlignmentsForRange(AlignmentTrack track, String chr, int start, int end, int zoom) throws IOException {
 
-        Collection<AlignmentInterval> loadedIntervals = track.getDataManager().getAllLoadedIntervals();
+        Collection<AlignmentInterval> loadedIntervals = track.getDataManager().getLoadedIntervals();
         List<Alignment> alignments = new ArrayList<Alignment>();
         for (AlignmentInterval interval : loadedIntervals) {
             if (interval.overlaps(chr, start, end)) {
@@ -475,23 +490,21 @@ public abstract class PluginSource<E extends Feature, D extends Feature> {
      */
     protected final FeatureDecoder<D> instantiateDecodingCodec(String decodingCodec, URL[] libURLs) {
         if (decodingCodec == null) {
-            FeatureCodec<D> knownCodec = CodecFactory.getCodec("." + parser.format, GenomeManager.getInstance().getCurrentGenome());
+            FeatureCodec<D, ?> knownCodec = CodecFactory.getCodec("." + parser.format, GenomeManager.getInstance().getCurrentGenome());
             if (knownCodec == null) {
                 throw new IllegalArgumentException("Unable to find codec for format " + parser.format);
             } else if (knownCodec instanceof AsciiFeatureCodec) {
                 return new AsciiDecoder.DecoderWrapper<D>((AsciiFeatureCodec) knownCodec);
             } else {
-                return new FeatureCodecDecoder<D>(knownCodec);
+                return new FeatureCodecDecoder<D>((FeatureCodec<D, PositionalBufferedStream>) knownCodec);
             }
         }
 
         try {
 
             if (libURLs == null) libURLs = new URL[0];
-            ClassLoader loader = URLClassLoader.newInstance(libURLs,
-                    getClass().getClassLoader());
 
-            Class clazz = loader.loadClass(decodingCodec);
+            Class clazz = RuntimeUtils.loadClassForName(decodingCodec, libURLs);
             Constructor constructor = clazz.getConstructor();
             Object codec = constructor.newInstance();
             //User can pass in LineFeatureDecoder, we just wrap it
@@ -612,6 +625,9 @@ public abstract class PluginSource<E extends Feature, D extends Feature> {
             for (Argument argument : v.arg) {
                 Object oVal = null;
                 switch (argument.getType()) {
+                    case BOOL:
+                        oVal = Boolean.parseBoolean(argument.value.get(0));
+                        break;
                     case LONGTEXT:
                     case TEXT:
                         oVal = argument.value.get(0);
@@ -673,6 +689,10 @@ public abstract class PluginSource<E extends Feature, D extends Feature> {
                             values.add(fTrack.getId());
                         }
                         break;
+                    case BOOL:
+                        sval = Boolean.toString((Boolean) loopEntry.getValue());
+                        values = Arrays.asList(sval);
+                        break;
                     case LONGTEXT:
                     case TEXT:
                         sval = (String) loopEntry.getValue();
