@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.feature;
@@ -31,8 +45,7 @@ import java.lang.reflect.Proxy;
 public class Exon extends AbstractFeature implements IExon {
 
     /**
-     * The index of the exon relative to the start codon.  The exon with the start
-     * codon is number "1".
+     * Index relative to the 5' end.
      */
     private int number;
 
@@ -116,7 +129,6 @@ public class Exon extends AbstractFeature implements IExon {
     }
 
 
-
     public Exon(BasicFeature bf) {
         this.start = bf.getStart();
         this.end = bf.getEnd();
@@ -187,16 +199,16 @@ public class Exon extends AbstractFeature implements IExon {
         return noncoding ? 0 : Math.max(0, codingEnd - codingStart);
     }
 
-    public AminoAcidSequence getAminoAcidSequence(Genome genome) {
+    public AminoAcidSequence getAminoAcidSequence(Genome genome, Exon prevExon, Exon nextExon) {
         if (aminoAcidSequence == null ||
                 //If the stored sequence was computed with a different codon table, we reset
                 !(Objects.equal(aminoAcidSequence.getCodonTableKey(), AminoAcidManager.getInstance().getCodonTable().getKey()))) {
-            computeAminoAcidSequence(genome);
+            computeAminoAcidSequence(genome, prevExon, nextExon);
         }
         return aminoAcidSequence;
     }
 
-    private void computeAminoAcidSequence(Genome genome) {
+    private void computeAminoAcidSequence(Genome genome, Exon prevExon, Exon nextExon) {
         if (noncoding) {
             return;
         }
@@ -204,13 +216,35 @@ public class Exon extends AbstractFeature implements IExon {
         int end = getEnd();
         String chr = getChr();
         if (readingFrame >= 0) {
-            int readStart = (codingStart > start) ? codingStart : start + readingFrame;
+            int readStart = (codingStart > start) ? codingStart : start;
             int readEnd = Math.min(end, codingEnd);
             if (readEnd > readStart + 3) {
                 if (seqBytes == null) {
                     seqBytes = genome.getSequence(chr, readStart, readEnd);
                 }
                 if (seqBytes != null) {
+
+                    // Grab nucleotides from previous exon if needed to complete first codon
+                    if (readingFrame > 0 && prevExon != null) {
+                        int diff = 3 - readingFrame;
+                        byte[] d = genome.getSequence(chr, prevExon.getCdEnd() - diff, prevExon.getCdEnd());
+                        byte[] tmp = new byte[d.length + seqBytes.length];
+                        System.arraycopy(d, 0, tmp, 0, diff);
+                        System.arraycopy(seqBytes, 0, tmp, diff, seqBytes.length);
+                        seqBytes = tmp;
+                        readStart -= diff;
+                    }
+
+                    // Grab nucleotides from next exon if needed for last codon
+                    int diff = 3 - ((readEnd - (codingStart + readingFrame)) % 3);
+                    if (diff > 0 && diff < 3 && nextExon != null) {
+                        byte[] d = genome.getSequence(chr, nextExon.getCdStart(), nextExon.getCdStart() + diff);
+                        byte[] tmp = new byte[d.length + seqBytes.length];
+                        System.arraycopy(seqBytes, 0, tmp, 0, seqBytes.length);
+                        System.arraycopy(d, 0, tmp, seqBytes.length, d.length);
+                        seqBytes = tmp;
+                    }
+
                     aminoAcidSequence = AminoAcidManager.getInstance().getAminoAcidSequence(getStrand(), readStart, seqBytes);
                 }
             }
@@ -230,18 +264,21 @@ public class Exon extends AbstractFeature implements IExon {
     }
 
     public String getValueString(double position, WindowFunction windowFunction) {
-        String msg = number > 0 ? "Exon number: " + number : "";
+
+        StringBuffer buffer = new StringBuffer();
+
+        if (number > 0) buffer.append("Exon number: " + number + "<br>");
         int aaNumber = this.getAminoAcidNumber((int) position);
         if (aaNumber > 0) {
-            msg += "<br>Amino acid number: " + aaNumber;
+            buffer.append("Amino acid codingNumber: " + aaNumber + "<br>");
         }
-        msg += "<br>" + getLocusString();
-        if (description != null) msg += "<br>" + description;
+        buffer.append(getLocusString());
+        if (description != null) buffer.append("<br>" + description);
         if (attributes != null) {
-            msg += getAttributeString();
+            buffer.append(getAttributeString());
         }
 
-        return msg;
+        return buffer.toString();
     }
 
     public void setNumber(int number) {
