@@ -1,13 +1,28 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.feature.genome;
 
 import org.apache.log4j.Logger;
@@ -55,8 +70,8 @@ public class GenomeBuilderPane extends javax.swing.JPanel implements Serializabl
         return cytobandFile;
     }
 
-    public String getRefFlatFileName() {
-        String refFlatFile = refFlatFileTextField.getText();
+    public String getGeneAnnotFileName() {
+        String refFlatFile = geneAnnotFileTextField.getText();
         if (refFlatFile != null && refFlatFile.trim().equals("")) {
             refFlatFile = null;
         }
@@ -224,10 +239,10 @@ public class GenomeBuilderPane extends javax.swing.JPanel implements Serializabl
         cytobandFileLabel = new JLabel();
         cytobandFileTextField = new JTextField();
         cytobandFileButton = new JButton();
-        refFlatFileLabel = new JLabel();
-        refFlatFileTextField = new JTextField();
-        refFlatFileButton = new JButton();
-        refFlatFileLabel2 = new JLabel();
+        geneAnnotFileLabel = new JLabel();
+        geneAnnotFileTextField = new JTextField();
+        geneAnnotFileButton = new JButton();
+        aliasFileLabel = new JLabel();
         chrAliasField = new JTextField();
         chrAliasButton = new JButton();
         vSpacer2 = new JPanel(null);
@@ -303,7 +318,7 @@ public class GenomeBuilderPane extends javax.swing.JPanel implements Serializabl
             //======== panel1 ========
             {
                 panel1.setBorder(new TitledBorder(null, "Optional", TitledBorder.LEADING, TitledBorder.DEFAULT_POSITION,
-                        new Font("Lucida Grande", Font.BOLD, 13)));
+                    new Font("Lucida Grande", Font.BOLD, 13)));
                 panel1.setLayout(null);
 
                 //---- cytobandFileLabel ----
@@ -329,33 +344,33 @@ public class GenomeBuilderPane extends javax.swing.JPanel implements Serializabl
                 panel1.add(cytobandFileButton);
                 cytobandFileButton.setBounds(698, 22, 83, cytobandFileButton.getPreferredSize().height);
 
-                //---- refFlatFileLabel ----
-                refFlatFileLabel.setText("Gene file");
-                panel1.add(refFlatFileLabel);
-                refFlatFileLabel.setBounds(15, 56, 84, 29);
+                //---- geneAnnotFileLabel ----
+                geneAnnotFileLabel.setText("Gene file");
+                panel1.add(geneAnnotFileLabel);
+                geneAnnotFileLabel.setBounds(15, 56, 84, 29);
 
-                //---- refFlatFileTextField ----
-                refFlatFileTextField.setToolTipText("An annotation file");
-                refFlatFileTextField.setPreferredSize(new Dimension(400, 28));
-                refFlatFileTextField.setMinimumSize(new Dimension(25, 28));
-                panel1.add(refFlatFileTextField);
-                refFlatFileTextField.setBounds(145, 56, 548, 29);
+                //---- geneAnnotFileTextField ----
+                geneAnnotFileTextField.setToolTipText("An annotation file");
+                geneAnnotFileTextField.setPreferredSize(new Dimension(400, 28));
+                geneAnnotFileTextField.setMinimumSize(new Dimension(25, 28));
+                panel1.add(geneAnnotFileTextField);
+                geneAnnotFileTextField.setBounds(145, 56, 548, 29);
 
-                //---- refFlatFileButton ----
-                refFlatFileButton.setText("Browse");
-                refFlatFileButton.addActionListener(new ActionListener() {
+                //---- geneAnnotFileButton ----
+                geneAnnotFileButton.setText("Browse");
+                geneAnnotFileButton.addActionListener(new ActionListener() {
                     @Override
                     public void actionPerformed(ActionEvent e) {
                         refFlatFileButtonActionPerformed(e);
                     }
                 });
-                panel1.add(refFlatFileButton);
-                refFlatFileButton.setBounds(698, 56, 83, refFlatFileButton.getPreferredSize().height);
+                panel1.add(geneAnnotFileButton);
+                geneAnnotFileButton.setBounds(698, 56, 83, geneAnnotFileButton.getPreferredSize().height);
 
-                //---- refFlatFileLabel2 ----
-                refFlatFileLabel2.setText("Alias file");
-                panel1.add(refFlatFileLabel2);
-                refFlatFileLabel2.setBounds(15, 90, 84, 29);
+                //---- aliasFileLabel ----
+                aliasFileLabel.setText("Alias file");
+                panel1.add(aliasFileLabel);
+                aliasFileLabel.setBounds(15, 90, 84, 29);
 
                 //---- chrAliasField ----
                 chrAliasField.setPreferredSize(new Dimension(400, 28));
@@ -404,7 +419,7 @@ public class GenomeBuilderPane extends javax.swing.JPanel implements Serializabl
         File directory = PreferenceManager.getInstance().getDefineGenomeInputDirectory();
         File file = FileDialogUtils.chooseFile("Select Annotation File", directory, FileDialogUtils.LOAD);
         if (file != null) {
-            refFlatFileTextField.setText(file.getAbsolutePath());
+            geneAnnotFileTextField.setText(file.getAbsolutePath());
             PreferenceManager.getInstance().setDefineGenomeInputDirectory(file.getParentFile());
         }
     }
@@ -433,10 +448,10 @@ public class GenomeBuilderPane extends javax.swing.JPanel implements Serializabl
     private JLabel cytobandFileLabel;
     private JTextField cytobandFileTextField;
     private JButton cytobandFileButton;
-    private JLabel refFlatFileLabel;
-    private JTextField refFlatFileTextField;
-    private JButton refFlatFileButton;
-    private JLabel refFlatFileLabel2;
+    private JLabel geneAnnotFileLabel;
+    private JTextField geneAnnotFileTextField;
+    private JButton geneAnnotFileButton;
+    private JLabel aliasFileLabel;
     private JTextField chrAliasField;
     private JButton chrAliasButton;
     private JPanel vSpacer2;
