@@ -1,13 +1,28 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 /*
  * GenomeManager.java
  *
@@ -1295,16 +1310,19 @@ public class GenomeManager {
      * Download a fasta file. Also attempts to download the index, and create an index
      * if that download fails
      *
-     * @param fastaPath     Full source path of fasta
+     * @param path     Full source path of fasta
      * @param targetDir     Destination directory for fasta file
      * @param targetName    Destination file name for fasta file
      * @param dialogsParent Parent of progress dialog shown. None shown if null
      * @return
      * @throws IOException
      */
-    private RunnableResult downloadFasta(String fastaPath, File targetDir, String targetName, Frame dialogsParent) throws IOException {
+    private RunnableResult downloadFasta(String path, File targetDir, String targetName, Frame dialogsParent) throws IOException {
         //Simple case, just need to copy fasta and create index
         File destFile = new File(targetDir, targetName);
+
+        String fastaPath = convertToS3(path);
+
         //TODO PROMPT TO OVERWRITE IF FILE EXISTS
         URLDownloader urlDownloader = HttpUtils.getInstance().downloadFile(fastaPath, destFile, dialogsParent, "Downloading genome sequence");
         RunnableResult fastaResult = urlDownloader.getResult();
@@ -1325,6 +1343,20 @@ public class GenomeManager {
         return fastaResult;
     }
 
+    /**
+     * Specific to Broad Amazon servers -- use S3 downwload rather than cloudfront
+     * @param path
+     * @return
+     */
+    private String convertToS3(String path) {
+        if(path.startsWith("http://igvdata") || path.startsWith("https://igvdata")) {
+            return path.replaceFirst("igvdata", "igv");
+        }
+        else {
+            return path;
+        }
+    }
+
     /**
      * Rewrite the {@link Globals#GENOME_ARCHIVE_SEQUENCE_FILE_LOCATION_KEY} property to equal
      * the specified {@code newSequencePath}. Works by creating a temp file and renaming
