@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.feature.tribble;
@@ -14,6 +28,7 @@ package org.broad.igv.feature.tribble;
 import htsjdk.samtools.util.BlockCompressedInputStream;
 import org.apache.log4j.Logger;
 import org.broad.igv.data.cufflinks.FPKMTrackingCodec;
+import org.broad.igv.feature.FeatureType;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.gwas.EQTLCodec;
 import org.broad.igv.peaks.PeakCodec;
@@ -79,10 +94,12 @@ public class CodecFactory {
         } else if (fn.endsWith(".bed")) {
             final IGVBEDCodec codec = new IGVBEDCodec(genome);
             if (fn.endsWith("junctions.bed")) {
-                codec.setSpliceJunctions(true);
+                codec.setFeatureType(FeatureType.SPLICE_JUNCTION);
             }
             return codec;
-        } else if (fn.endsWith(".dgv")) {
+        } else if (fn.endsWith(".gappedpeak")) {
+            return new IGVBEDCodec(genome, FeatureType.GAPPED_PEAK);
+        }else if (fn.endsWith(".dgv")) {
             return new DGVCodec(genome);
         } else if (fn.contains("refflat")) {
             return new UCSCGeneTableCodec(UCSCGeneTableCodec.Type.REFFLAT, genome);
@@ -102,7 +119,7 @@ public class CodecFactory {
             return new PSLCodec(genome);
         } else if (MUTCodec.isMutationAnnotationFile(locator)) {
             return new MUTCodec(path, genome);
-        } else if (fn.endsWith(".narrowpeak") || fn.endsWith(".broadpeak")) {
+        } else if (fn.endsWith(".narrowpeak") || fn.endsWith(".broadpeak") ) {
             return new EncodePeakCodec(genome);
         } else if (fn.endsWith(".peak")) {
             return new PeakCodec(genome);
