@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.feature.tribble;
@@ -114,8 +128,11 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
             trackProperties = new TrackProperties();
             ParsingUtils.parseTrackLine(line, trackProperties);
             header.setTrackProperties(trackProperties);
-        } else if (line.startsWith("##gff-version") && line.endsWith("3")) {
-            helper = new GFF3Helper();
+        } else if (line.startsWith("##gff-version") && line.contains("3")) {
+            String[] tokens = Globals.whitespacePattern.split(line);
+            if (tokens.length > 1 && tokens[1].startsWith("3")) {
+                helper = new GFF3Helper();
+            }
         } else if (line.startsWith("#nodecode") || line.startsWith("##nodecode")) {
             helper.setUrlDecoding(false);
         } else if (line.startsWith("#hide") || line.startsWith("##hide")) {
@@ -174,7 +191,8 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
      * @return true if potentialInput can be parsed, false otherwise
      */
     public boolean canDecode(String path) {
-        final String pathLowerCase = path.toLowerCase();
+        String pathLowerCase = path.toLowerCase();
+        if (pathLowerCase.endsWith(".gz")) pathLowerCase = pathLowerCase.substring(0, pathLowerCase.length() - 3);
         return pathLowerCase.endsWith(".gff") || pathLowerCase.endsWith(".gff3") ||
                 pathLowerCase.endsWith(".gvf") || pathLowerCase.endsWith(".gtf");
     }
@@ -211,7 +229,7 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
             return null;
         }
 
-        String chromosome = genome == null ? StringUtils.intern(chrToken) : genome.getChromosomeAlias(chrToken);
+        String chromosome = genome == null ? StringUtils.intern(chrToken) : genome.getCanonicalChrName(chrToken);
 
         // GFF coordinates are 1-based inclusive (length = end - start + 1)
         // IGV (UCSC) coordinates are 0-based exclusive.  Adjust start and end accordingly
@@ -386,7 +404,7 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
                     if (attributes.containsKey(possName)) {
                         String parent = attributes.get(possName).trim();
                         if (parent.length() > 0) {
-                            return new String[] {parent};
+                            return new String[]{parent};
                         }
                     }
                 }
@@ -406,12 +424,12 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
             for (String nf : idFields) {
                 if (attributes.containsKey(nf)) {
                     String tmp = attributes.get(nf).trim();
-                    if(tmp.length() > 0) return tmp;
+                    if (tmp.length() > 0) return tmp;
                 }
             }
 
             String tmp = getName(attributes);
-            if(tmp != null && tmp.trim().length() > 0) {
+            if (tmp != null && tmp.trim().length() > 0) {
                 return tmp.trim();
             }
 
