@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.feature.tribble;
@@ -80,7 +94,7 @@ public class UCSCGeneTableCodec extends UCSCCodec<BasicFeature> {
      *
      * @param line the input line to decode
      * @return Return the Feature encoded by the line,  or null if the line does not represent a feature (e.g. is
-     *         a comment)
+     * a comment)
      */
     public BasicFeature decode(String line) {
         if (line.startsWith("#")) {
@@ -108,7 +122,7 @@ public class UCSCGeneTableCodec extends UCSCCodec<BasicFeature> {
         }
 
         String chrToken = tokens[chrColumn].trim();
-        String chr = genome == null ? StringUtils.intern(chrToken) : genome.getChromosomeAlias(chrToken);
+        String chr = genome == null ? StringUtils.intern(chrToken) : genome.getCanonicalChrName(chrToken);
 
         int start = Integer.parseInt(tokens[startColumn]);
         int end = Integer.parseInt(tokens[endColumn]);
@@ -136,6 +150,12 @@ public class UCSCGeneTableCodec extends UCSCCodec<BasicFeature> {
         if (tokenCount > 8) {
             createExons(tokens, tokenCount, gene, chr, strand);
         }
+
+        // Optional standard name column
+        if (tokenCount > 16) {
+            gene.setAttribute("Standard Name", tokens[16]);
+        }
+
         return gene;
     }
 
@@ -169,20 +189,24 @@ public class UCSCGeneTableCodec extends UCSCCodec<BasicFeature> {
         String[] endsBuffer = Globals.commaPattern.split(tokens[endsBufferColumn]);
 
         if (startsBuffer.length == endsBuffer.length) {
+
             int exonNumber = (strand == Strand.NEGATIVE ? exonCount : 1);
+
             for (int i = 0; i < startsBuffer.length; i++) {
                 int exonStart = Integer.parseInt(startsBuffer[i]);
                 int exonEnd = Integer.parseInt(endsBuffer[i]);
                 Exon exon = new Exon(chr, exonStart, exonEnd, strand);
                 exon.setCodingStart(cdStart);
                 exon.setCodingEnd(cdEnd);
-                exon.setNumber(exonNumber);
                 gene.addExon(exon);
+
+                exon.setNumber(exonNumber);
                 if (strand == Strand.NEGATIVE) {
                     exonNumber--;
                 } else {
                     exonNumber++;
                 }
+
             }
         }
 
