@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.gs;
@@ -153,23 +167,6 @@ public class GSUtils {
         if (tokenFile.exists()) {
             tokenFile.delete();
         }
-
-
-        try {
-            URI gsURI = new URI(PreferenceManager.getInstance().get(PreferenceManager.GENOME_SPACE_DM_SERVER));
-            CookieManager manager = (CookieManager) CookieManager.getDefault();
-            if (manager == null) return;
-            final CookieStore cookieStore = manager.getCookieStore();
-            List<HttpCookie> cookies = new ArrayList<HttpCookie>(cookieStore.get(gsURI));
-            for (HttpCookie cookie : cookies) {
-                final String name = cookie.getName();
-                if (name.equals("gs-token") || name.equals("gs-username")) {
-                    cookieStore.remove(gsURI, cookie);
-                }
-            }
-        } catch (URISyntaxException e) {
-            log.error("Error creating GS URI", e);
-        }
     }
 
     private static void writeToFile(String line, File aFile) {
@@ -191,13 +188,36 @@ public class GSUtils {
 
 
     public static boolean isGenomeSpace(URL url) {
-        return url.getHost().contains(".genomespace.org");
+        //String dmServer = getDMHost();
+        //String atmServer = getATMHost();
+        return url.getHost().contains("genomespace.org");
+    }
+
+    private synchronized static String getDMHost() {
+        try {
+            return (new URL(PreferenceManager.getInstance().get(PreferenceManager.GENOME_SPACE_DM_SERVER))).getHost();
+        } catch (MalformedURLException e) {
+            log.error(e);
+            return null;
+        }
+    }
+
+
+    private synchronized static String getATMHost() {
+
+        try {
+            return (new URL(PreferenceManager.getInstance().get(PreferenceManager.GENOME_SPACE_ATM_SERVER))).getHost();
+        } catch (MalformedURLException e) {
+            log.error(e);
+            return null;
+        }
+
     }
 
     /**
      * Convert GenomeSpace format string to igv format type (extension)
-     *   Example: https://dmtest.genomespace.org:8444/datamanager/files/users/SAGDemo/Step1/TF.data.tab
-     *     ?dataformat=http://www.genomespace.org/datamanager/dataformat/gct/0.0.0
+     * Example: https://dmtest.genomespace.org:8444/datamanager/files/users/SAGDemo/Step1/TF.data.tab
+     * ?dataformat=http://www.genomespace.org/datamanager/dataformat/gct/0.0.0
      *
      * @param format
      * @return
