@@ -1,25 +1,31 @@
 /*
- * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
+ * The MIT License (MIT)
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
- * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
- * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
- * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
- * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
- * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
- * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
- * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
- * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
- * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.peaks;
 
 import org.broad.igv.data.DataSource;
-import org.broad.igv.data.LocusScoreUtils;
 import org.broad.igv.feature.FeatureUtils;
 import org.broad.igv.feature.LocusScore;
 import org.broad.igv.feature.genome.Genome;
@@ -60,6 +66,9 @@ public class PeakTrack extends AbstractTrack {
     private static ColorOption colorOption = ColorOption.SCORE;
     private static boolean showPeaks = true;
     private static boolean showSignals = false;
+    static boolean commandBarAdded = false;
+    static int timeStep = 0;
+    static boolean animate = false;
 
     int nTimePoints;
 
@@ -81,8 +90,6 @@ public class PeakTrack extends AbstractTrack {
     DataRange scoreDataRange = new DataRange(0, 0, 100);
     DataRange signalDataRange = new DataRange(0, 0, 1000f);
 
-    static boolean commandBarAdded = false;
-
     int bandHeight;
     int signalHeight;
     int peakHeight;
@@ -108,7 +115,7 @@ public class PeakTrack extends AbstractTrack {
     public PeakTrack(final ResourceLocator locator, Genome genome) throws IOException {
         super(locator);
         this.genome = genome;
-        setHeight(30);
+        setHeight(20);
 
 
         try {
@@ -143,9 +150,9 @@ public class PeakTrack extends AbstractTrack {
 
     /**
      * timePoints=0,30,60,120
-     * peaks=http://www.broadinstitute.org/igvdata/ichip/peaks/AHR.peak
-     * signals=http://www.broadinstitute.org/igvdata/ichip/tdf/compressed/AHR.merged.bam.tdf
-     * timeSignals=http://www.broadinstitute.org/igvdata/ichip/tdf/timecourses/AHR_0/AHR_0.merged.bam.tdf,http...
+     * peaks=http://data.broadinstitute.org/igvdata/ichip/peaks/AHR.peak
+     * signals=http://data.broadinstitute.org/igvdata/ichip/tdf/compressed/AHR.merged.bam.tdf
+     * timeSignals=http://data.broadinstitute.org/igvdata/ichip/tdf/timecourses/AHR_0/AHR_0.merged.bam.tdf,http...
      *
      * @param path
      * @throws IOException
@@ -225,7 +232,7 @@ public class PeakTrack extends AbstractTrack {
     }
 
     @Override
-    public void preload(RenderContext context) {
+    public void load(RenderContext context) {
         try {
             getFilteredPeaks(context.getChr());
         } catch (IOException e) {
@@ -245,7 +252,7 @@ public class PeakTrack extends AbstractTrack {
             renderer.render(peakList, context, rect, this);
 
         } catch (IOException e) {
-             log.error("Error loading peaks", e);
+            log.error("Error loading peaks", e);
         }
     }
 
@@ -268,10 +275,9 @@ public class PeakTrack extends AbstractTrack {
         }
     }
 
-
     @Override
-    public void setHeight(int h) {
-        super.setHeight(h);
+    public void setHeight(int h, boolean force) {
+        super.setHeight(h, force);
 
         int nBands = getDisplayMode() == DisplayMode.COLLAPSED ? 1 : nTimePoints;
 
@@ -284,14 +290,52 @@ public class PeakTrack extends AbstractTrack {
     @Override
     public void setDisplayMode(DisplayMode mode) {
         super.setDisplayMode(mode);
-        if (mode == Track.DisplayMode.COLLAPSED) {
-            setHeight(bandHeight);
-        } else {
+        if (mode == Track.DisplayMode.EXPANDED) {
             setHeight(nTimePoints * bandHeight + gapHeight);
+        } else {
+            setHeight(bandHeight);
         }
     }
 
 
+    public static void setAnimate(boolean animate) {
+        PeakTrack.animate = animate;
+        if(animate) {
+            startAnimationThread();
+        }
+    }
+
+    private static synchronized void startAnimationThread() {
+
+        timeStep = 0;
+
+        Runnable runnable = new Runnable() {
+            @Override
+            public void run() {
+
+                while (animate) {
+                    try {
+                        Thread.sleep(1000) ;
+                        timeStep ++;
+                        if(timeStep == 4) {
+                            Thread.sleep(500);
+                            timeStep = 0;
+                        }
+                        IGV.getInstance().doRefresh();
+
+                    } catch (InterruptedException e) {
+                        setAnimate(false);
+                        return;
+                    }
+                }
+            }
+        };
+
+        (new Thread(runnable)).start();
+
+    }
+
+
     public String getValueStringAt(String chr, double position, int y, ReferenceFrame frame) {
         try {
             boolean foundValue = false;
@@ -337,7 +381,7 @@ public class PeakTrack extends AbstractTrack {
             // give a 2 pixel window, otherwise very narrow features will be missed.
             double bpPerPixel = frame.getScale();
             int buffer = (int) (2 * bpPerPixel);    /* * */
-            return LocusScoreUtils.getFeatureAt(position, buffer, scores);
+            return FeatureUtils.getFeatureAt(position, buffer, scores);
         }
     }
 
@@ -422,6 +466,8 @@ public class PeakTrack extends AbstractTrack {
     }
 
 
+
+
     public float getRegionScore(String chr, int start, int end, int zoom, RegionScoreType type, String frameName) {
 
         int interval = end - start;
@@ -504,6 +550,10 @@ public class PeakTrack extends AbstractTrack {
         showSignals = b;
     }
 
+    public int getTimeStep() {
+        return timeStep;
+    }
+
     public DataSource[] getTimeSignalSources() {
 
         if (timeSignalSources == null) {
