@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -20,14 +34,14 @@ import org.broad.igv.track.Track;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.variant.VariantTrack;
-import org.broad.tribble.util.ParsingUtils;
-import org.broadinstitute.sting.gatk.walkers.na12878kb.core.MongoVariantContext;
-import org.broadinstitute.sting.gatk.walkers.na12878kb.core.NA12878DBArgumentCollection;
-import org.broadinstitute.sting.gatk.walkers.na12878kb.core.NA12878KnowledgeBase;
-import org.broadinstitute.sting.gatk.walkers.na12878kb.core.TruthStatus;
-import org.broadinstitute.variant.variantcontext.Genotype;
-import org.broadinstitute.variant.variantcontext.GenotypeType;
-import org.broadinstitute.variant.variantcontext.VariantContext;
+import htsjdk.tribble.util.ParsingUtils;
+import org.broadinstitute.gatk.tools.walkers.na12878kb.core.MongoVariantContext;
+import org.broadinstitute.gatk.tools.walkers.na12878kb.core.NA12878DBArgumentCollection;
+import org.broadinstitute.gatk.tools.walkers.na12878kb.core.NA12878KnowledgeBase;
+import org.broadinstitute.gatk.tools.walkers.na12878kb.core.TruthStatus;
+import htsjdk.variant.variantcontext.Genotype;
+import htsjdk.variant.variantcontext.GenotypeType;
+import htsjdk.variant.variantcontext.VariantContext;
 
 import javax.swing.*;
 import javax.swing.border.EmptyBorder;
@@ -49,7 +63,10 @@ public class VariantReviewDialog extends JDialog {
     private VariantContext variantContext;
     private String userName;
 
-    public VariantReviewDialog(Frame owner, VariantContext vc) {
+    //Path to spec file describing database
+    private String dbSpecPath;
+
+    public VariantReviewDialog(Frame owner, VariantContext vc, String dbSpecPath) {
         super(owner);
         initComponents();
 
@@ -57,6 +74,7 @@ public class VariantReviewDialog extends JDialog {
         genotypeTypeField.setModel(new DefaultComboBoxModel(GenotypeType.values()));
         this.variantContext = vc;
         this.userName = System.getProperty("user.name", "unknown");
+        this.dbSpecPath = dbSpecPath;
 
         initComponentData(vc);
     }
@@ -89,6 +107,7 @@ public class VariantReviewDialog extends JDialog {
 
         String callsetName = callsetField.getText();
         TruthStatus truthStatus = (TruthStatus) truthField.getSelectedItem();
+        boolean isComplexEvent = isComplexEventCB.isSelected();
 
         int allele0 = -1;
         int allele1 = -1;
@@ -107,16 +126,16 @@ public class VariantReviewDialog extends JDialog {
                 break;
         }
 
-        MongoVariantContext mvc = VariantReviewSource.createMVC(allele0, allele1, callsetName, variantContext, truthStatus);
-        String errorMessage = addCall(VariantReviewPlugin.getDbSpecPath(), mvc);
+        MongoVariantContext mvc = VariantReviewSource.createMVC(allele0, allele1, callsetName, variantContext, truthStatus, isComplexEvent);
+        String errorMessage = addCall(this.dbSpecPath, mvc);
 
         if (errorMessage != null) {
             MessageUtils.showErrorMessage(errorMessage, new IOException(errorMessage));
         } else {
             setVisible(false);
             //Find the track showing results, clear it to force a refresh
-            for(Track t: IGV.getInstance().getFeatureTracks()){
-                if(t instanceof VariantTrack){
+            for (Track t : IGV.getInstance().getFeatureTracks()) {
+                if (t instanceof VariantTrack) {
                     ((VariantTrack) t).clearPackedFeatures();
                 }
             }
@@ -126,11 +145,12 @@ public class VariantReviewDialog extends JDialog {
 
     /**
      * Add the specified mvc to the specified database
+     *
      * @param dbSpecPath
      * @param mvc
      * @return
      */
-    static String addCall(String dbSpecPath, MongoVariantContext mvc){
+    static String addCall(String dbSpecPath, MongoVariantContext mvc) {
 
         NA12878DBArgumentCollection args = new NA12878DBArgumentCollection(dbSpecPath);
 
@@ -142,7 +162,7 @@ public class VariantReviewDialog extends JDialog {
             errorMessage = wr.getError();
         } catch (Exception ex) {
             errorMessage = ex.getMessage();
-            if(errorMessage == null) errorMessage = "" + ex;
+            if (errorMessage == null) errorMessage = "" + ex;
         } finally {
             if (kb != null) kb.close();
         }
@@ -221,6 +241,10 @@ public class VariantReviewDialog extends JDialog {
         panel6 = new JPanel();
         label9 = new JLabel();
         stopField = new JLabel();
+        panel8 = new JPanel();
+        hSpacer6 = new JPanel(null);
+        isComplexEventCB = new JCheckBox();
+        hSpacer7 = new JPanel(null);
         buttonBar = new JPanel();
         okButton = new JButton();
         cancelButton = new JButton();
@@ -232,7 +256,7 @@ public class VariantReviewDialog extends JDialog {
         //======== dialogPane ========
         {
             dialogPane.setBorder(new EmptyBorder(12, 12, 12, 12));
-            dialogPane.setPreferredSize(new Dimension(600, 115));
+            dialogPane.setPreferredSize(new Dimension(600, 150));
             dialogPane.setLayout(new BorderLayout());
 
             //======== contentPanel ========
@@ -400,14 +424,30 @@ public class VariantReviewDialog extends JDialog {
                 }
                 contentPanel.add(panel6);
             }
-            dialogPane.add(contentPanel, BorderLayout.CENTER);
+            dialogPane.add(contentPanel, BorderLayout.NORTH);
+
+            //======== panel8 ========
+            {
+                panel8.setLayout(new BoxLayout(panel8, BoxLayout.X_AXIS));
+
+                //---- hSpacer6 ----
+                hSpacer6.setMaximumSize(new Dimension(300, 32767));
+                hSpacer6.setPreferredSize(new Dimension(115, 10));
+                panel8.add(hSpacer6);
+
+                //---- isComplexEventCB ----
+                isComplexEventCB.setText("Complex Event");
+                panel8.add(isComplexEventCB);
+                panel8.add(hSpacer7);
+            }
+            dialogPane.add(panel8, BorderLayout.CENTER);
 
             //======== buttonBar ========
             {
                 buttonBar.setBorder(new EmptyBorder(12, 0, 0, 0));
                 buttonBar.setLayout(new GridBagLayout());
-                ((GridBagLayout)buttonBar.getLayout()).columnWidths = new int[] {0, 85, 80};
-                ((GridBagLayout)buttonBar.getLayout()).columnWeights = new double[] {1.0, 0.0, 0.0};
+                ((GridBagLayout) buttonBar.getLayout()).columnWidths = new int[]{0, 85, 80};
+                ((GridBagLayout) buttonBar.getLayout()).columnWeights = new double[]{1.0, 0.0, 0.0};
 
                 //---- okButton ----
                 okButton.setText("Save");
@@ -418,8 +458,8 @@ public class VariantReviewDialog extends JDialog {
                     }
                 });
                 buttonBar.add(okButton, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0,
-                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
-                    new Insets(0, 0, 0, 5), 0, 0));
+                        GridBagConstraints.CENTER, GridBagConstraints.BOTH,
+                        new Insets(0, 0, 0, 5), 0, 0));
 
                 //---- cancelButton ----
                 cancelButton.setText("Cancel");
@@ -430,13 +470,13 @@ public class VariantReviewDialog extends JDialog {
                     }
                 });
                 buttonBar.add(cancelButton, new GridBagConstraints(2, 0, 1, 1, 0.0, 0.0,
-                    GridBagConstraints.CENTER, GridBagConstraints.BOTH,
-                    new Insets(0, 0, 0, 0), 0, 0));
+                        GridBagConstraints.CENTER, GridBagConstraints.BOTH,
+                        new Insets(0, 0, 0, 0), 0, 0));
             }
-            dialogPane.add(buttonBar, BorderLayout.PAGE_END);
+            dialogPane.add(buttonBar, BorderLayout.SOUTH);
         }
         contentPane.add(dialogPane, BorderLayout.CENTER);
-        setSize(700, 135);
+        setSize(700, 160);
         setLocationRelativeTo(getOwner());
         // JFormDesigner - End of component initialization  //GEN-END:initComponents
     }
@@ -471,6 +511,10 @@ public class VariantReviewDialog extends JDialog {
     private JPanel panel6;
     private JLabel label9;
     private JLabel stopField;
+    private JPanel panel8;
+    private JPanel hSpacer6;
+    private JCheckBox isComplexEventCB;
+    private JPanel hSpacer7;
     private JPanel buttonBar;
     private JButton okButton;
     private JButton cancelButton;
