@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -26,6 +40,7 @@ import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.UIConstants;
+import org.broad.igv.ui.color.ColorUtilities;
 import org.broad.igv.util.SOLIDUtils;
 
 import java.awt.*;
@@ -34,33 +49,20 @@ import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
 
+
 /**
  * @author jrobinso
  */
 public class SequenceRenderer {
 
+
     private static Logger log = Logger.getLogger(SequenceRenderer.class);
 
     //Maximum scale at which the track is displayed
     //public static final int MAX_SCALE_FOR_RENDER = 1000;
     public static final int AMINO_ACID_RESOLUTION = 5;
-    public static Map<Character, Color> nucleotideColors = new HashMap();
 
-
-    static {
-        Color AColor = new Color(0, 150, 0);
-        nucleotideColors.put('A', AColor);
-        nucleotideColors.put('a', AColor);
-        nucleotideColors.put('C', Color.BLUE);
-        nucleotideColors.put('c', Color.BLUE);
-        nucleotideColors.put('T', Color.RED);
-        nucleotideColors.put('t', Color.RED);
-        Color GColor = new Color(209, 113, 5);
-        nucleotideColors.put('G', GColor);
-        nucleotideColors.put('g', GColor);
-        nucleotideColors.put('N', Color.gray);
-        nucleotideColors.put('n', Color.gray);
-    }
+    private static Map<Character, Color> nucleotideColors;
 
     protected TranslatedSequenceDrawer translatedSequenceDrawer;
 
@@ -71,9 +73,45 @@ public class SequenceRenderer {
     private boolean hasSequence = true;
 
     public SequenceRenderer() {
+
+        if(nucleotideColors == null) setNucleotideColors();
+
         translatedSequenceDrawer = new TranslatedSequenceDrawer();
     }
 
+
+    public static Map<Character, Color> getNucleotideColors() {
+
+        if(nucleotideColors == null) setNucleotideColors();
+        return nucleotideColors;
+
+    }
+
+    public static void setNucleotideColors() {
+
+        PreferenceManager prefs = PreferenceManager.getInstance();
+
+        nucleotideColors = new HashMap();
+
+        Color a = ColorUtilities.stringToColor(prefs.get(PreferenceManager.COLOR_A), new Color(0, 150, 0));
+        Color c = ColorUtilities.stringToColor(prefs.get(PreferenceManager.COLOR_C), Color.blue);
+        Color t = ColorUtilities.stringToColor(prefs.get(PreferenceManager.COLOR_T),  Color.red);
+        Color g = ColorUtilities.stringToColor(prefs.get(PreferenceManager.COLOR_G),  Color.gray);
+        Color n = ColorUtilities.stringToColor(prefs.get(PreferenceManager.COLOR_N),  Color.gray);
+
+        nucleotideColors.put('A', a);
+        nucleotideColors.put('a', a);
+        nucleotideColors.put('C', c);
+        nucleotideColors.put('c', c);
+        nucleotideColors.put('T', t);
+        nucleotideColors.put('t', t);
+        nucleotideColors.put('G', g);
+        nucleotideColors.put('g', g);
+        nucleotideColors.put('N', n);
+        nucleotideColors.put('n', n);
+
+    }
+
     /**
      * @param context
      * @param trackRectangle
