@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -29,30 +43,30 @@ public interface Alignment extends LocusScore {
 
     String getReadSequence();
 
-    // For legacy apps
-
-    String getChromosome();
-
     String getChr();
 
     int getAlignmentStart();
 
+    int getAlignmentEnd();
+
     boolean contains(double location);
 
     AlignmentBlock[] getAlignmentBlocks();
 
     AlignmentBlock[] getInsertions();
 
-    char[] getGapTypes();
-
     String getCigarString();
 
+    char[] getGapTypes();
+
     int getInferredInsertSize();
 
     int getMappingQuality();
 
     ReadMate getMate();
 
+    Strand getReadStrand();
+
     boolean isProperPair();
 
     boolean isMapped();
@@ -63,41 +77,44 @@ public interface Alignment extends LocusScore {
 
     boolean isSecondOfPair(); // Ben Berman
 
-    Strand getFirstOfPairStrand();
-
-    Strand getSecondOfPairStrand();
-
     boolean isNegativeStrand();
 
     boolean isDuplicate();
 
-    int getAlignmentEnd();
+    boolean isPrimary();
+
+    boolean isSupplementary();
 
     byte getBase(double position);
 
     byte getPhred(double position);
 
-    String getSample();
-
-    String getReadGroup();
-
     Object getAttribute(String key);
 
+    void setMateSequence(String sequence);
+
     String getPairOrientation();
 
-    boolean isSmallInsert();
+    Strand getFirstOfPairStrand();
+
+    Strand getSecondOfPairStrand();
 
     boolean isVendorFailedRead();
 
-    Color getDefaultColor();
+    /**
+     * Return an explicitly set color for this alignment, if any  (typically null).
+     * @return
+     */
+    Color getColor();
+
+    String getSample();
+
+    String getReadGroup();
 
     String getLibrary();
 
     String getClipboardString(double location);
 
-    Strand getReadStrand();
 
     void finish();
-
-    boolean isPrimary();
 }
