@@ -1,13 +1,28 @@
 /*
- * Copyright (c) 2007-2014 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.sam;
 
 import com.google.common.eventbus.EventBus;
@@ -43,18 +58,16 @@ public class AlignmentDataManager implements IAlignmentDataManager {
     private PositionCache<AlignmentInterval> loadedIntervalCache = new PositionCache<AlignmentInterval>();
     private PositionCache<PackedAlignments> packedAlignmentsCache = new PositionCache<PackedAlignments>();
 
+    private ResourceLocator locator;
     private HashMap<String, String> chrMappings = new HashMap();
     private volatile boolean isLoading = false;
     private AlignmentTileLoader reader;
     private CoverageTrack coverageTrack;
-
     private Map<String, PEStats> peStats;
-
     private AlignmentTrack.ExperimentType experimentType;
-
     private SpliceJunctionHelper.LoadOptions loadOptions;
-
     private Object loadLock = new Object();
+    private boolean showAlignments = true;
 
     /**
      * This {@code EventBus} is typically used to notify listeners when new data
@@ -62,7 +75,6 @@ public class AlignmentDataManager implements IAlignmentDataManager {
      */
     private EventBus eventBus = new EventBus();
 
-    private ResourceLocator locator;
 
     public AlignmentDataManager(ResourceLocator locator, Genome genome) throws IOException {
         this.locator = locator;
@@ -85,7 +97,7 @@ public class AlignmentDataManager implements IAlignmentDataManager {
             List<String> seqNames = reader.getSequenceNames();
             if (seqNames != null) {
                 for (String chr : seqNames) {
-                    String alias = genome.getChromosomeAlias(chr);
+                    String alias = genome.getCanonicalChrName(chr);
                     chrMappings.put(alias, chr);
                 }
             }
@@ -128,6 +140,13 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         return coverageTrack;
     }
 
+    public double getMinVisibleScale() {
+        PreferenceManager prefs = PreferenceManager.getInstance();
+        float maxRange = prefs.getAsFloat(PreferenceManager.SAM_MAX_VISIBLE_RANGE);
+        return (maxRange * 1000) / 700;
+    }
+
+
     /**
      * The set of sequences found in the file.
      * May be null
@@ -233,7 +252,7 @@ public class AlignmentDataManager implements IAlignmentDataManager {
             int adjustedStart = start;
             int adjustedEnd = end;
             // Expand the interval by the lesser of  +/- a 2 screens, or max visible range
-            int windowSize = Math.min(4*(end - start), PreferenceManager.getInstance().getAsInt(PreferenceManager.SAM_MAX_VISIBLE_RANGE) * 1000);
+            int windowSize = Math.min(4 * (end - start), PreferenceManager.getInstance().getAsInt(PreferenceManager.SAM_MAX_VISIBLE_RANGE) * 1000);
             int center = (end + start) / 2;
             int expand = Math.max(end - start, windowSize / 2);
 
@@ -269,6 +288,13 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         packedAlignmentsCache.clear();
     }
 
+    public void dumpAlignments() {
+        packedAlignmentsCache.clear();
+        for (AlignmentInterval interval : loadedIntervalCache.values()) {
+            interval.dumpAlignments();
+        }
+    }
+
     public synchronized void loadAlignments(final String chr, final int start, final int end,
                                             final AlignmentTrack.RenderOptions renderOptions,
                                             final RenderContext context) {
@@ -292,7 +318,6 @@ public class AlignmentDataManager implements IAlignmentDataManager {
                 AlignmentInterval loadedInterval = loadInterval(chr, start, end, renderOptions);
                 loadedIntervalCache.put(loadedInterval.getRange(), loadedInterval);
 
-                List<ReferenceFrame> frameList = context != null ? Arrays.asList(context.getReferenceFrame()) : null;
                 packAlignments(renderOptions);
                 getEventBus().post(new DataLoadedEvent(context));
 
@@ -325,7 +350,7 @@ public class AlignmentDataManager implements IAlignmentDataManager {
 
         SpliceJunctionHelper spliceJunctionHelper = new SpliceJunctionHelper(this.loadOptions);
         AlignmentTileLoader.AlignmentTile t = reader.loadTile(sequence, start, end, spliceJunctionHelper,
-                downsampleOptions, peStats, bisulfiteContext, monitor);
+                downsampleOptions, peStats, bisulfiteContext, showAlignments, monitor);
 
         List<Alignment> alignments = t.getAlignments();
         List<DownsampledInterval> downsampledIntervals = t.getDownsampledIntervals();
@@ -418,6 +443,11 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         coverageTrack.setSnpThreshold(PreferenceManager.getInstance().getAsFloat(PreferenceManager.SAM_ALLELE_THRESHOLD));
     }
 
+    public void setShowAlignments(boolean showAlignments) {
+        this.showAlignments = showAlignments;
+        clear();
+    }
+
     public static class DownsampleOptions {
         private boolean downsample;
         private int sampleWindowSize;
