@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -27,6 +41,7 @@ import org.broad.igv.goby.GobyCountArchiveDataSource;
 import org.broad.igv.renderer.BarChartRenderer;
 import org.broad.igv.renderer.DataRange;
 import org.broad.igv.renderer.DataRenderer;
+import org.broad.igv.renderer.GraphicUtils;
 import org.broad.igv.session.IGVSessionReader;
 import org.broad.igv.session.SubtlyImportant;
 import org.broad.igv.tdf.TDFDataSource;
@@ -35,6 +50,7 @@ import org.broad.igv.track.*;
 import org.broad.igv.ui.DataRangeDialog;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.color.ColorUtilities;
+import org.broad.igv.ui.event.AlignmentTrackEvent;
 import org.broad.igv.ui.event.DataLoadedEvent;
 import org.broad.igv.ui.event.ViewChange;
 import org.broad.igv.ui.panel.FrameManager;
@@ -42,6 +58,7 @@ import org.broad.igv.ui.panel.IGVPopupMenu;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.FileDialogUtils;
 import org.broad.igv.ui.util.MessageUtils;
+import org.broad.igv.ui.util.UIUtilities;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.StringUtils;
 
@@ -75,18 +92,21 @@ public class CoverageTrack extends AbstractTrack {
     public static final boolean DEFAULT_SHOW_REFERENCE = false;
 
     // User settable state -- these attributes should be stored in the session file
-    @XmlAttribute private float snpThreshold;
+    @XmlAttribute
+    private float snpThreshold;
     //TODO This appears to not be used anywhere, remove?
-    @XmlAttribute boolean showReference;
+    @XmlAttribute
+    private boolean showReference;
 
-    AlignmentDataManager dataManager;
-    CoverageDataSource dataSource;
-    DataRenderer dataSourceRenderer;
-    IntervalRenderer intervalRenderer;
-    PreferenceManager prefs;
-    JMenuItem dataRangeItem;
-    JMenuItem autoscaleItem;
-    Genome genome;
+    private AlignmentTrack alignmentTrack;
+    private AlignmentDataManager dataManager;
+    private CoverageDataSource dataSource;
+    private DataRenderer dataSourceRenderer;
+    private IntervalRenderer intervalRenderer;
+    private PreferenceManager prefs;
+    private JMenuItem dataRangeItem;
+    private Genome genome;
+    private boolean removed = false;
 
     /**
      * Whether to autoscale across all ReferenceFrames
@@ -101,15 +121,16 @@ public class CoverageTrack extends AbstractTrack {
      *
      * @param track
      */
-    public CoverageTrack(CoverageTrack track){
-        this(track.getResourceLocator(), track.getName(), track.genome);
-        if(track.dataManager != null) this.setDataManager(track.dataManager);
-        if(track.dataSource != null) this.setDataSource(track.dataSource);
+    public CoverageTrack(CoverageTrack track) {
+        this(track.getResourceLocator(), track.getName(), track.alignmentTrack, track.genome);
+        if (track.dataManager != null) this.setDataManager(track.dataManager);
+        if (track.dataSource != null) this.setDataSource(track.dataSource);
     }
 
-    public CoverageTrack(ResourceLocator locator, String name, Genome genome) {
+    public CoverageTrack(ResourceLocator locator, String name, AlignmentTrack alignmentTrack, Genome genome) {
         super(locator, locator.getPath() + "_coverage", name);
         super.setDataRange(new DataRange(0, 0, 60));
+        this.alignmentTrack = alignmentTrack;
         this.genome = genome;
         intervalRenderer = new IntervalRenderer();
         setMaximumHeight(40);
@@ -137,7 +158,7 @@ public class CoverageTrack extends AbstractTrack {
 
     }
 
-    public void setSnpThreshold(float snpThreshold){
+    public void setSnpThreshold(float snpThreshold) {
         this.snpThreshold = snpThreshold;
     }
 
@@ -154,16 +175,31 @@ public class CoverageTrack extends AbstractTrack {
         this.renderOptions = renderOptions;
     }
 
-    AlignmentTrack.RenderOptions getRenderOptions(){
+    AlignmentTrack.RenderOptions getRenderOptions() {
         return this.renderOptions;
     }
 
+    public boolean isRemoved() {
+        return removed;
+    }
+
+    @Override
+    public void dispose() {
+        super.dispose();
+        removed = true;
+        dataManager = null;
+        dataSource = null;
+        alignmentTrack = null;
+        setVisible(false);
+    }
+
     /**
      * Rescale as necessary, and tell components to repaint
+     *
      * @param e
      */
     @Subscribe
-    public void receiveDataLoaded(DataLoadedEvent e){
+    public void receiveDataLoaded(DataLoadedEvent e) {
         ReferenceFrame frame = e.context.getReferenceFrame();
         rescale(frame);
         frame.getEventBus().post(new ViewChange.Result());
@@ -171,8 +207,8 @@ public class CoverageTrack extends AbstractTrack {
 
     public void rescale(ReferenceFrame iframe) {
         List<ReferenceFrame> frameList = new ArrayList<ReferenceFrame>();
-        if(iframe != null) frameList.add(iframe);
-        if(globalAutoScale){
+        if (iframe != null) frameList.add(iframe);
+        if (globalAutoScale) {
             frameList.addAll(FrameManager.getFrames());
         }
 
@@ -197,34 +233,38 @@ public class CoverageTrack extends AbstractTrack {
         }
     }
 
-    public void render(RenderContext context, Rectangle rect){
+    public void render(RenderContext context, Rectangle rect) {
+
+        if (context.getScale() > dataManager.getMinVisibleScale() && dataSource == null) {
+            Rectangle visibleRect = context.getVisibleRect().intersection(rect);
+            Graphics2D g = context.getGraphic2DForColor(Color.gray);
+            GraphicUtils.drawCenteredText("Zoom in to see coverage.", visibleRect, g);
+            return;
+        }
+
 
         overlay(context, rect);
 
         drawBorder(context, rect);
+
+        // TODO -- What is this all about ??? JTR
         List<LocusScore> scores = getSummaryScores(context);
         if (scores != null) {
             dataSourceRenderer.renderBorder(this, context, rect);
         }
 
-        if(!isRepeatY(rect)){
-            lastRenderY = rect.y;
-            if(dataSourceRenderer != null){
-                dataSourceRenderer.renderAxis(this, context, rect);
-            }
-            if(FrameManager.isExomeMode()){
-                int x = context.getGraphics().getClipBounds().x;
-                Rectangle scaleRect = new Rectangle(x, rect.y, rect.width, rect.height);
-                drawScale(context, scaleRect);
-            }
-
+        if (dataSourceRenderer != null) {
+            dataSourceRenderer.renderAxis(this, context, rect);
+        }
+        else {
+            DataRenderer.drawScale(this.getDataRange(), context, rect);
         }
-
     }
 
-    private List<LocusScore> getSummaryScores(RenderContext context){
+
+    private List<LocusScore> getSummaryScores(RenderContext context) {
         List<LocusScore> scores = null;
-        if(dataSource != null){
+        if (dataSource != null) {
             String chr = context.getChr();
             int start = (int) context.getOrigin();
             int end = (int) context.getEndLocation();
@@ -248,7 +288,7 @@ public class CoverageTrack extends AbstractTrack {
             }
             if (interval != null) {
                 if (interval.contains(context.getChr(), (int) context.getOrigin(), (int) context.getEndLocation())) {
-                    if(autoScale) rescale(context.getReferenceFrame());
+                    if (autoScale) rescale(context.getReferenceFrame());
                     intervalRenderer.paint(context, rect, interval.getCounts());
                     return;
                 }
@@ -265,6 +305,7 @@ public class CoverageTrack extends AbstractTrack {
 
     /**
      * Draw border and scale
+     *
      * @param context
      * @param rect
      */
@@ -272,10 +313,6 @@ public class CoverageTrack extends AbstractTrack {
         context.getGraphic2DForColor(Color.gray).drawLine(
                 rect.x, rect.y + rect.height,
                 rect.x + rect.width, rect.y + rect.height);
-
-        if(!FrameManager.isExomeMode()){
-            drawScale(context, rect);
-        }
     }
 
     public void drawScale(RenderContext context, Rectangle rect) {
@@ -360,21 +397,22 @@ public class CoverageTrack extends AbstractTrack {
 
             // First pass, coverage
             int lastpX = -1;
-            //for (AlignmentCounts alignmentCounts : countList) {
+
             int start = alignmentCounts.getStart();
+            int step = alignmentCounts.getBucketSize();
             int nPoints = alignmentCounts.getNumberOfPoints();
             boolean isSparse = alignmentCounts instanceof SparseAlignmentCounts;
 
             for (int idx = 0; idx < nPoints; idx++) {
 
-                int pos = isSparse ? ((SparseAlignmentCounts) alignmentCounts).getPosition(idx) : start + idx;
+                int pos = isSparse ? ((SparseAlignmentCounts) alignmentCounts).getPosition(idx) : start + idx * step;
                 int pX = (int) (rectX + (pos - origin) / scale);
 
                 if (pX > rectMaxX) {
                     break; // We're done,  data is position sorted so we're beyond the right-side of the view
                 }
 
-                int dX = (int) (rectX + (pos + 1 - origin) / scale) - pX;
+                int dX = (int) (rectX + (pos + step - origin) / scale) - pX;
                 dX = dX < 1 ? 1 : dX;
                 if (pX + dX > lastpX) {
                     int pY = (int) rectMaxY - 1;
@@ -394,97 +432,95 @@ public class CoverageTrack extends AbstractTrack {
                     lastpX = pX + dX;
                 }
             }
-            //}
-
 
             // Second pass - mark mismatches
-            lastpX = -1;
-            //for (AlignmentCounts alignmentCounts : countList) {
 
-            BisulfiteCounts bisulfiteCounts = alignmentCounts.getBisulfiteCounts();
-            final int intervalEnd = alignmentCounts.getEnd();
-            final int intervalStart = alignmentCounts.getStart();
-            byte[] refBases = null;
+            if (alignmentCounts.hasBaseCounts()) {
 
-            // Dont try to compute mismatches for intervals > 10 MB
-            if ((intervalEnd - intervalStart) < TEN_MB) {
-                refBases = genome.getSequence(context.getChr(), intervalStart, intervalEnd);
-            }
+                lastpX = -1;
+                BisulfiteCounts bisulfiteCounts = alignmentCounts.getBisulfiteCounts();
+                final int intervalEnd = alignmentCounts.getEnd();
+                final int intervalStart = alignmentCounts.getStart();
+                byte[] refBases = null;
 
-
-            start = alignmentCounts.getStart();
-            nPoints = alignmentCounts.getNumberOfPoints();
-            isSparse = alignmentCounts instanceof SparseAlignmentCounts;
-
-            for (int idx = 0; idx < nPoints; idx++) {
-                int pos = isSparse ? ((SparseAlignmentCounts) alignmentCounts).getPosition(idx) : start + idx;
-
-                BisulfiteCounts.Count bc = null;
-                if (bisulfiteMode && bisulfiteCounts != null) {
-                    bc = bisulfiteCounts.getCount(pos);
+                // Dont try to compute mismatches for intervals > 10 MB
+                if ((intervalEnd - intervalStart) < TEN_MB) {
+                    refBases = genome.getSequence(context.getChr(), intervalStart, intervalEnd);
                 }
 
-                int pX = (int) (rectX + (pos - origin) / scale);
 
-                if (pX > rectMaxX) {
-                    break; // We're done,  data is position sorted so we're beyond the right-side of the view
-                }
+                start = alignmentCounts.getStart();
+                nPoints = alignmentCounts.getNumberOfPoints();
+                isSparse = alignmentCounts instanceof SparseAlignmentCounts;
 
-                int dX = (int) (rectX + (pos + 1 - origin) / scale) - pX;
-                dX = dX < 1 ? 1 : dX;
-                if (pX + dX > lastpX) {
+                for (int idx = 0; idx < nPoints; idx++) {
+                    int pos = isSparse ? ((SparseAlignmentCounts) alignmentCounts).getPosition(idx) : start + idx;
+
+                    BisulfiteCounts.Count bc = null;
+                    if (bisulfiteMode && bisulfiteCounts != null) {
+                        bc = bisulfiteCounts.getCount(pos);
+                    }
+
+                    int pX = (int) (rectX + (pos - origin) / scale);
+
+                    if (pX > rectMaxX) {
+                        break; // We're done,  data is position sorted so we're beyond the right-side of the view
+                    }
+
+                    int dX = (int) (rectX + (pos + 1 - origin) / scale) - pX;
+                    dX = dX < 1 ? 1 : dX;
+                    if (pX + dX > lastpX) {
 
 
-                    // Test to see if any single nucleotide mismatch  (nucleotide other than the reference)
-                    // has a quality weight > 20% of the total
-                    // Skip this test if the position is in the list of known snps or if the reference is unknown
-                    boolean mismatch = false;
+                        // Test to see if any single nucleotide mismatch  (nucleotide other than the reference)
+                        // has a quality weight > 20% of the total
+                        // Skip this test if the position is in the list of known snps or if the reference is unknown
+                        boolean mismatch = false;
 
-                    if (refBases != null) {
-                        int refIdx = pos - intervalStart;
-                        if (refIdx >= 0 && refIdx < refBases.length) {
+                        if (refBases != null) {
+                            int refIdx = pos - intervalStart;
+                            if (refIdx >= 0 && refIdx < refBases.length) {
+                                if (bisulfiteMode) {
+                                    mismatch = (bc != null && (bc.methylatedCount + bc.unmethylatedCount) > 0);
+                                } else {
+                                    byte ref = refBases[refIdx];
+                                    mismatch = alignmentCounts.isMismatch(pos, ref, context.getChr(), snpThreshold);
+                                }
+                            }
+                        }
+
+                        if (!mismatch) {
+                            continue;
+                        }
+
+                        int pY = (int) rectMaxY - 1;
+
+                        int totalCount = alignmentCounts.getTotalCount(pos);
+                        double tmp = range.isLog() ? Math.log10(totalCount + 1) / maxRange : totalCount / maxRange;
+                        int height = (int) (tmp * rectHeight);
+
+                        height = Math.min(height, rect.height - 1);
+
+                        if (dX > 3) {
+                            dX--; // Create a little space between bars when there is room.
+                        }
+
+                        if (height > 0) {
                             if (bisulfiteMode) {
-                                mismatch = (bc != null && (bc.methylatedCount + bc.unmethylatedCount) > 0);
+                                if (bc != null) {
+                                    drawBarBisulfite(context, pos, rect, totalCount, maxRange,
+                                            pY, pX, dX, bc, range.isLog());
+                                }
                             } else {
-                                byte ref = refBases[refIdx];
-                                mismatch = alignmentCounts.isMismatch(pos, ref, context.getChr(), snpThreshold);
+                                drawBar(context, pos, rect, totalCount, maxRange,
+                                        pY, pX, dX, alignmentCounts, range.isLog());
                             }
                         }
+                        lastpX = pX + dX;
+
                     }
-
-                    if (!mismatch) {
-                        continue;
-                    }
-
-                    int pY = (int) rectMaxY - 1;
-
-                    int totalCount = alignmentCounts.getTotalCount(pos);
-                    double tmp = range.isLog() ? Math.log10(totalCount + 1) / maxRange : totalCount / maxRange;
-                    int height = (int) (tmp * rectHeight);
-
-                    height = Math.min(height, rect.height - 1);
-
-                    if (dX > 3) {
-                        dX--; // Create a little space between bars when there is room.
-                    }
-
-                    if (height > 0) {
-                        if (bisulfiteMode) {
-                            if (bc != null) {
-                                drawBarBisulfite(context, pos, rect, totalCount, maxRange,
-                                        pY, pX, dX, bc, range.isLog());
-                            }
-                        } else {
-                            drawBar(context, pos, rect, totalCount, maxRange,
-                                    pY, pX, dX, alignmentCounts, range.isLog());
-                        }
-                    }
-                    lastpX = pX + dX;
-
                 }
             }
-            //}
-
         }
     }
 
@@ -704,9 +740,9 @@ public class CoverageTrack extends AbstractTrack {
 
         popupMenu.addSeparator();
         addLoadCoverageDataItem(popupMenu);
-        popupMenu.addSeparator();
 
-        popupMenu.add(TrackMenuUtils.getRemoveMenuItem(tmp));
+        popupMenu.addSeparator();
+        addShowItems(popupMenu);
 
         return popupMenu;
     }
@@ -793,9 +829,62 @@ public class CoverageTrack extends AbstractTrack {
         return maxValItem;
     }
 
+    public void addShowItems(JPopupMenu menu) {
+
+        if(alignmentTrack != null) {
+            final JMenuItem alignmentItem = new JCheckBoxMenuItem("Show Alignment Track");
+            alignmentItem.setSelected(alignmentTrack.isVisible());
+            alignmentItem.setEnabled(!alignmentTrack.isRemoved());
+            alignmentItem.addActionListener(new ActionListener() {
+                @Override
+                public void actionPerformed(ActionEvent e) {
+                    alignmentTrack.onAlignmentTrackEvent(new AlignmentTrackEvent(CoverageTrack.this, AlignmentTrackEvent.Type.VISIBLE, alignmentItem.isSelected()));
+                    if (alignmentItem.isSelected()) {
+                        alignmentTrack.onAlignmentTrackEvent(new AlignmentTrackEvent(CoverageTrack.this, AlignmentTrackEvent.Type.RELOAD));
+                    }
+                }
+            });
+            menu.add(alignmentItem);
+
+            final SpliceJunctionTrack spliceJunctionTrack = alignmentTrack.getSpliceJunctionTrack();
+            if (spliceJunctionTrack != null) {
+                final JMenuItem junctionItem = new JCheckBoxMenuItem("Show Splice Junction Track");
+                junctionItem.setSelected(spliceJunctionTrack.isVisible());
+                junctionItem.setEnabled(!spliceJunctionTrack.isRemoved());
+                junctionItem.addActionListener(new ActionListener() {
+                    @Override
+                    public void actionPerformed(ActionEvent e) {
+                        alignmentTrack.onAlignmentTrackEvent(new AlignmentTrackEvent(CoverageTrack.this, AlignmentTrackEvent.Type.SPLICE_JUNCTION, junctionItem.isSelected()));
+                        IGV.getInstance().getMainPanel().revalidate();
+                    }
+                });
+
+                menu.add(junctionItem);
+            }
+
+            final JMenuItem coverageItem = new JMenuItem("Hide Track");
+            coverageItem.setEnabled(!isRemoved());
+            coverageItem.addActionListener(new ActionListener() {
+                @Override
+                public void actionPerformed(ActionEvent e) {
+                    UIUtilities.invokeOnEventThread(new Runnable() {
+
+                        public void run() {
+                            setVisible(false);
+                            IGV.getInstance().getMainPanel().revalidate();
+
+                        }
+                    });
+                }
+            });
+            menu.add(coverageItem);
+        }
+    }
+
+
     public void addLoadCoverageDataItem(JPopupMenu menu) {
         // Change track height by attribute
-        final JMenuItem item = new JCheckBoxMenuItem("Load coverage data...");
+        final JMenuItem item = new JCheckBoxMenuItem("Load pre-computed coverage data...");
         item.addActionListener(new ActionListener() {
 
             public void actionPerformed(ActionEvent e) {
@@ -822,13 +911,14 @@ public class CoverageTrack extends AbstractTrack {
             }
         });
 
+        item.setEnabled(dataSource == null);
         menu.add(item);
 
     }
 
-    public void addAutoscaleItem(JPopupMenu menu,final ReferenceFrame frame) {
+    public void addAutoscaleItem(JPopupMenu menu, final ReferenceFrame frame) {
         // Change track height by attribute
-        autoscaleItem = new JCheckBoxMenuItem("Autoscale");
+        final JMenuItem autoscaleItem = new JCheckBoxMenuItem("Autoscale");
         autoscaleItem.setSelected(autoScale);
         autoscaleItem.addActionListener(new ActionListener() {
 
