@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.sam;
@@ -118,32 +132,6 @@ public class DenseAlignmentCounts extends BaseAlignmentCounts {
         }
     }
 
-    public int getNegTotal(int pos) {
-        int offset = pos - start;
-        if (offset < 0 || offset >= posA.length) {
-            if (log.isDebugEnabled()) {
-                log.debug("Position out of range: " + pos + " (valid range - " + start + "-" + end);
-            }
-            return 0;
-        } else {
-            return negTotal[offset];
-
-        }
-    }
-
-    public int getPosTotal(int pos) {
-        int offset = pos - start;
-        if (offset < 0 || offset >= posA.length) {
-            if (log.isDebugEnabled()) {
-                log.debug("Position out of range: " + pos + " (valid range - " + start + "-" + end);
-            }
-            return 0;
-        } else {
-            return posTotal[offset];
-
-        }
-    }
-
     public int getTotalQuality(int pos) {
         int offset = pos - start;
         if (offset < 0 || offset >= posA.length) {
@@ -298,11 +286,6 @@ public class DenseAlignmentCounts extends BaseAlignmentCounts {
         }
     }
 
-    public int getAvgQuality(int pos, byte b) {
-        int count = getCount(pos, b);
-        return count == 0 ? 0 : getQuality(pos, b) / count;
-    }
-
 
     protected void incrementDeletion(int pos, boolean negativeStrand) {
         int offset = pos - start;
@@ -340,7 +323,7 @@ public class DenseAlignmentCounts extends BaseAlignmentCounts {
             for (int i = 0; i < bases.length; i++) {
                 int pos = start + i;
                 // NOTE:  the direct access block.qualities is intentional,  profiling reveals this to be a critical bottleneck
-                byte q = block.qualities[i];
+                byte q = ((AlignmentBlockImpl) block).qualities[i];
                 // TODO -- handle "=" in cigar string with no read bases
                 byte n = bases[i];
                 incPositionCount(pos, n, q, isNegativeStrand);
