@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -47,6 +61,7 @@ public abstract class SAMAlignment implements Alignment {
     public static final char HARD_CLIP = 'H';
     public static final char PADDING = 'P';
     public static final char ZERO_GAP = 'O';
+    public static final char UNKNOWN = 0;
     public static final String REDUCE_READS_TAG = "RR";
 
     /**
@@ -83,8 +98,8 @@ public abstract class SAMAlignment implements Alignment {
     protected String sample;
 
     ReadMate mate;
-    AlignmentBlock[] alignmentBlocks;
-    AlignmentBlock[] insertions;
+    AlignmentBlockImpl[] alignmentBlocks;
+    AlignmentBlockImpl[] insertions;
     char[] gapTypes;
     private static final DecimalFormat DECIMAL_FORMAT = new DecimalFormat();
 
@@ -134,7 +149,7 @@ public abstract class SAMAlignment implements Alignment {
         return alignmentBlocks;
     }
 
-    public AlignmentBlock[] getInsertions() {
+    public AlignmentBlockImpl[] getInsertions() {
         return insertions;
     }
 
@@ -149,7 +164,7 @@ public abstract class SAMAlignment implements Alignment {
         for (AlignmentBlock block : this.alignmentBlocks) {
             if (block.contains(basePosition)) {
                 int offset = basePosition - block.getStart();
-                byte base = block.getBases()[offset];
+                byte base = block.getBase(offset);
                 return base;
             }
         }
@@ -229,8 +244,8 @@ public abstract class SAMAlignment implements Alignment {
                                          short[] flowSignals, String flowOrder, int flowOrderStart) {
 
         if (cigarString.equals("*")) {
-            alignmentBlocks = new AlignmentBlock[1];
-            alignmentBlocks[0] = new AlignmentBlock(getChr(), getStart(), readBases, readBaseQualities);
+            alignmentBlocks = new AlignmentBlockImpl[1];
+            alignmentBlocks[0] = new AlignmentBlockImpl(getChr(), getStart(), readBases, readBaseQualities);
             return;
         }
 
@@ -244,6 +259,7 @@ public abstract class SAMAlignment implements Alignment {
         boolean firstOperator = true;
         int softClippedBaseCount = 0;
         int nGaps = 0;
+        char prevOp = 0;
         for (CigarOperator operator : operators) {
 
             char op = operator.operator;
@@ -253,6 +269,9 @@ public abstract class SAMAlignment implements Alignment {
             int nBases = operator.nBases;
             if (operatorIsMatch(showSoftClipped, op)) {
                 nBlocks++;
+                if (operatorIsMatch(showSoftClipped, prevOp)) {
+                    nGaps++;
+                }
             } else if (op == DELETION || op == SKIPPED_REGION) {
                 nGaps++;
             } else if (op == INSERTION) {
@@ -267,11 +286,13 @@ public abstract class SAMAlignment implements Alignment {
             if (op != SOFT_CLIP) {
                 firstOperator = false;
             }
+
+            prevOp = op;
         }
 
 
-        alignmentBlocks = new AlignmentBlock[nBlocks];
-        insertions = new AlignmentBlock[nInsertions];
+        alignmentBlocks = new AlignmentBlockImpl[nBlocks];
+        insertions = new AlignmentBlockImpl[nInsertions];
         if (nGaps > 0) {
             gapTypes = new char[nGaps];
         }
@@ -294,6 +315,7 @@ public abstract class SAMAlignment implements Alignment {
             }
         }
 
+        prevOp = 0;
         for (CigarOperator op : operators) {
             try {
 
@@ -302,7 +324,7 @@ public abstract class SAMAlignment implements Alignment {
                 }
                 if (operatorIsMatch(showSoftClipped, op.operator)) {
 
-                    AlignmentBlock block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
+                    AlignmentBlockImpl block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
                             getChr(), blockStart, fromIdx, op.nBases, true);
 
                     if (op.operator == SOFT_CLIP) {
@@ -313,6 +335,9 @@ public abstract class SAMAlignment implements Alignment {
                     fromIdx += op.nBases;
                     blockStart += op.nBases;
 
+                    if (operatorIsMatch(showSoftClipped, prevOp)) {
+                        gapTypes[gapIdx++] = ZERO_GAP;
+                    }
 
                 } else if (op.operator == DELETION || op.operator == SKIPPED_REGION) {
                     blockStart += op.nBases;
@@ -321,7 +346,7 @@ public abstract class SAMAlignment implements Alignment {
                     // This gap is between blocks split by insertion.   It is a zero
                     // length gap but must be accounted for.
                     gapTypes[gapIdx++] = ZERO_GAP;
-                    AlignmentBlock block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
+                    AlignmentBlockImpl block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
                             getChr(), blockStart, fromIdx, op.nBases, false);
 
                     insertions[insertionIdx++] = block;
@@ -334,6 +359,7 @@ public abstract class SAMAlignment implements Alignment {
             } catch (Exception e) {
                 log.error("Error processing CIGAR string", e);
             }
+            prevOp = op.operator;
         }
 
         // Check for soft clipping at end
@@ -359,7 +385,6 @@ public abstract class SAMAlignment implements Alignment {
         StringBuilder buffer = new StringBuilder(4);
 
         // Create list of cigar operators
-        boolean firstOperator = true;
         CigarOperator prevOp = null;
         for (int i = 0; i < cigarString.length(); i++) {
             char next = cigarString.charAt(i);
@@ -386,13 +411,12 @@ public abstract class SAMAlignment implements Alignment {
 
     }
 
-    private static AlignmentBlock buildAlignmentBlock(FlowSignalContextBuilder fBlockBuilder, byte[] readBases,
-                                                      byte[] readBaseQualities, String chr, int blockStart,
-                                                      int fromIdx, int nBases, boolean checkNBasesAvailable) {
+    private static AlignmentBlockImpl buildAlignmentBlock(FlowSignalContextBuilder fBlockBuilder, byte[] readBases,
+                                                          byte[] readBaseQualities, String chr, int blockStart,
+                                                          int fromIdx, int nBases, boolean checkNBasesAvailable) {
 
         byte[] blockBases = new byte[nBases];
         byte[] blockQualities = new byte[nBases];
-        short[] blockCounts = new short[nBases];
 
         // TODO -- represent missing sequence ("*") explicitly for efficiency.
         int nBasesAvailable = nBases;
@@ -417,12 +441,12 @@ public abstract class SAMAlignment implements Alignment {
             System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, nBases);
         }
 
-        AlignmentBlock block;
+        AlignmentBlockImpl block;
         if (fBlockBuilder != null) {
-            block = AlignmentBlock.getInstance(chr, blockStart, blockBases, blockQualities,
+            block = new AlignmentBlockImpl(chr, blockStart, blockBases, blockQualities,
                     fBlockBuilder.getFlowSignalContext(readBases, fromIdx, nBases));
         } else {
-            block = AlignmentBlock.getInstance(chr, blockStart, blockBases, blockQualities);
+            block = new AlignmentBlockImpl(chr, blockStart, blockBases, blockQualities);
         }
 
         return block;
@@ -494,11 +518,16 @@ public abstract class SAMAlignment implements Alignment {
             buf.append("Read group = " + readGroup + "<br>");
         }
 
+        String cigarString = getCigarString();
+        if (cigarString.length() > 80) {
+            cigarString = cigarString.substring(0, 80) + "...";
+        }
+
         buf.append("----------------------" + "<br>");
         int basePosition = (int) position;
         buf.append("Location = " + getChr() + ":" + DECIMAL_FORMAT.format(1 + (long) position) + "<br>");
         buf.append("Alignment start = " + DECIMAL_FORMAT.format(getAlignmentStart() + 1) + " (" + (isNegativeStrand() ? "-" : "+") + ")<br>");
-        buf.append("Cigar = " + getCigarString() + "<br>");
+        buf.append("Cigar = " + cigarString + "<br>");
         buf.append("Mapped = " + (isMapped() ? "yes" : "no") + "<br>");
         buf.append("Mapping quality = " + getMappingQuality() + "<br>");
         buf.append("Secondary = " + (isPrimary() ? "no" : "yes") + "<br>");
@@ -528,32 +557,45 @@ public abstract class SAMAlignment implements Alignment {
                         buf.append("<br>");
                         for (offset = 0; offset < block.getLength(); offset++) {
                             byte base = block.getBase(offset);
-                            buf.append((char) base + ": ");
-                            bufAppendFlowSignals(block, buf, offset);
+                            if (base > 0) {
+                                buf.append((char) base + ": ");
+                                bufAppendFlowSignals(block, buf, offset);
+                            }
                         }
                         buf.append("----------------------"); // NB: no <br> required
                         return buf.toString();
                     } else {
-                        return "Insertion: " + new String(block.getBases());
+                        byte[] bases = block.getBases();
+
+                        return bases == null ?
+                                "Insertion: " + block.getLength() + " bases" :
+                                "Insertion: " + new String(block.getBases());
                     }
                 }
             }
         }
 
+        Genome genome = GenomeManager.getInstance().getCurrentGenome();
+
         for (AlignmentBlock block : this.alignmentBlocks) {
             if (block.contains(basePosition)) {
                 int offset = basePosition - block.getStart();
                 byte base = block.getBase(offset);
+
+                if (base == 0 && this.getReadSequence().equals("=") && !block.isSoftClipped() && genome != null) {
+                    base = genome.getReference(chr, basePosition);
+
+                }
+
                 byte quality = block.getQuality(offset);
                 buf.append("Base = " + (char) base + "<br>");
                 buf.append("Base phred quality = " + quality + "<br>");
-                if (block.hasCounts()) {
-                    buf.append("Count = " + block.getCount(offset) + "<br>");
-                }
+
                 // flow signals
                 if (block.hasFlowSignals()) {
                     bufAppendFlowSignals(block, buf, offset);
                 }
+
             }
         }
 
@@ -619,12 +661,6 @@ public abstract class SAMAlignment implements Alignment {
 
     abstract public int getAlignmentEnd();
 
-
-    public boolean isSmallInsert() {
-        int absISize = Math.abs(getInferredInsertSize());
-        return absISize > 0 && absISize <= getReadLength();
-    }
-
     public float getScore() {
         return getMappingQuality();
     }
@@ -677,10 +713,6 @@ public abstract class SAMAlignment implements Alignment {
     @Override
     public void finish() {
 
-        Genome genome = GenomeManager.getInstance().getCurrentGenome();
-        for (AlignmentBlock block : alignmentBlocks) {
-            block.reduce(genome);
-        }
     }
 
 
@@ -694,22 +726,6 @@ public abstract class SAMAlignment implements Alignment {
     }
 
 
-    /**
-     * Use blocks to recreate read sequence.
-     * As of this comment writing, we don't keep a block
-     * for hard-clipped bases, so this won't match what's in the file
-     *
-     * @return
-     */
-    String buildReadSequenceFromBlocks() {
-        String readSeq = "";
-        for (AlignmentBlock block : getAlignmentBlocks()) {
-            readSeq += new String(block.getBases());
-        }
-        return readSeq;
-    }
-
-
     @Override
     public void setMateSequence(String sequence) {
         this.mateSequence = sequence;
