@@ -1,23 +1,41 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.sam.reader;
 
-import net.sf.samtools.SAMFileHeader;
-import net.sf.samtools.SAMFileReader;
-import net.sf.samtools.SAMReadGroupRecord;
+import htsjdk.samtools.SAMFileHeader;
+import htsjdk.samtools.SAMFileReader;
+import htsjdk.samtools.SAMReadGroupRecord;
+import htsjdk.samtools.ValidationStringency;
 import org.apache.log4j.Logger;
 import org.broad.igv.exceptions.DataLoadException;
+import org.broad.igv.ga4gh.Ga4ghAPIHelper;
+import org.broad.igv.ga4gh.Ga4ghAlignmentReader;
+import org.broad.igv.ga4gh.Ga4ghProvider;
 import org.broad.igv.goby.GobyAlignmentQueryReader;
 import org.broad.igv.util.FileUtils;
-import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
 
@@ -34,7 +52,7 @@ public class AlignmentReaderFactory {
     private static Logger log = Logger.getLogger(AlignmentReaderFactory.class);
 
     static {
-        SAMFileReader.setDefaultValidationStringency(SAMFileReader.ValidationStringency.SILENT);
+        SAMFileReader.setDefaultValidationStringency(ValidationStringency.SILENT);
     }
 
     public static AlignmentReader getReader(String path, boolean requireIndex) throws IOException {
@@ -61,8 +79,7 @@ public class AlignmentReaderFactory {
         } else if (typeString.endsWith(".sam")) {
             reader = new SAMReader(samFile, requireIndex);
 
-        } else if (typeString.endsWith("sorted.txt")
-                || typeString.endsWith(".aligned")
+        } else if (typeString.endsWith(".aligned")
                 || typeString.endsWith(".aligned.txt")
                 || typeString.endsWith("bedz")
                 || typeString.endsWith("bed")
@@ -90,7 +107,12 @@ public class AlignmentReaderFactory {
                 throw new RuntimeException("Cannot load Goby alignment " + locator.getPath(), e);
 
             }
-        } else {
+        } else if (Ga4ghAlignmentReader.supportsFileType(locator.getType())) {
+            Ga4ghProvider provider = (Ga4ghProvider) locator.getAttribute("provider");
+            return new Ga4ghAlignmentReader(provider, locator.getPath());
+        }
+
+        else {
             throw new RuntimeException("Cannot find reader for aligment file: " + locator.getPath());
         }
 
@@ -116,6 +138,8 @@ public class AlignmentReaderFactory {
                     }
                 } else {
                     String f = nextLine.trim();
+                    if(f.length() == 0) continue;  // Empty line
+                    
                     for (Map.Entry<String, String> entry : replacements.entrySet()) {
                         f = f.replace(entry.getKey(), entry.getValue());
                     }
