@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -15,14 +29,15 @@
  */
 package org.broad.igv.sam.reader;
 
-import net.sf.samtools.SAMFileHeader;
-import net.sf.samtools.SAMFileReader;
-import net.sf.samtools.SAMFileReader.ValidationStringency;
-import net.sf.samtools.SAMRecordIterator;
-import net.sf.samtools.SAMSequenceRecord;
-import net.sf.samtools.util.CloseableIterator;
+import htsjdk.samtools.SAMFileHeader;
+import htsjdk.samtools.SAMFileReader;
+import htsjdk.samtools.ValidationStringency;
+import htsjdk.samtools.SAMRecordIterator;
+import htsjdk.samtools.SAMSequenceRecord;
+import htsjdk.samtools.util.CloseableIterator;
 import org.apache.log4j.Logger;
-import org.broad.igv.sam.Alignment;
+import org.broad.igv.sam.EmptyAlignmentIterator;
+import org.broad.igv.sam.PicardAlignment;
 import org.broad.igv.ui.util.MessageUtils;
 
 import java.io.File;
@@ -34,7 +49,7 @@ import java.util.Set;
 /**
  * @author jrobinso
  */
-public class BAMFileReader implements AlignmentReader {
+public class BAMFileReader implements AlignmentReader<PicardAlignment> {
 
     private static Logger log = Logger.getLogger(BAMFileReader.class);
     SAMFileReader reader;
@@ -52,7 +67,7 @@ public class BAMFileReader implements AlignmentReader {
         }
     }
 
-    private SAMFileHeader getHeader() {
+    public SAMFileHeader getFileHeader() {
         if (header == null) {
             loadHeader();
         }
@@ -60,7 +75,7 @@ public class BAMFileReader implements AlignmentReader {
     }
 
     public List<String> getSequenceNames() {
-        SAMFileHeader header = getHeader();
+        SAMFileHeader header = getFileHeader();
         if (header == null) {
             return null;
         }
@@ -76,7 +91,7 @@ public class BAMFileReader implements AlignmentReader {
     }
 
     public Set<String> getPlatforms() {
-        return AlignmentReaderFactory.getPlatforms(getHeader());
+        return AlignmentReaderFactory.getPlatforms(getFileHeader());
     }
 
     private void loadHeader() {
@@ -91,7 +106,7 @@ public class BAMFileReader implements AlignmentReader {
         return reader.hasIndex();
     }
 
-    public CloseableIterator<Alignment> query(String sequence, int start, int end, boolean contained) {
+    public CloseableIterator<PicardAlignment> query(String sequence, int start, int end, boolean contained) {
         SAMRecordIterator query = null;
         try {
             query = reader.query(sequence, start + 1, end, contained);
@@ -100,41 +115,15 @@ public class BAMFileReader implements AlignmentReader {
             log.error("Error querying BAM file ", e);
             MessageUtils.showMessage("Error reading bam file.  This usually indicates a problem with the index (bai) file." +
                     "<br>" + e.toString() + " (" + e.getMessage() + ")");
-            return EmptyIterator.instance;
+            return EmptyAlignmentIterator.getInstance();
         }
 
     }
 
-    public CloseableIterator<Alignment> iterator() {
+    public CloseableIterator<PicardAlignment> iterator() {
         return new WrappedIterator(reader.iterator());
     }
 
-
-    /**
-     * Class
-     */
-    public static class EmptyIterator implements CloseableIterator<Alignment> {
-
-        public static final EmptyIterator instance = new EmptyIterator();
-
-        public void close() {
-            // Ignore
-        }
-
-        public boolean hasNext() {
-            return false;
-        }
-
-        public Alignment next() {
-            return null;
-        }
-
-        public void remove() {
-
-        }
-    }
-
-
     /**
      * Look for BAM index file according to standard naming convention.  Slightly modified version of Picard
      * function of the same name.
