@@ -1,18 +1,32 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.session;
 
-//~--- non-JDK imports --------------------------------------------------------
-
 import org.apache.log4j.Logger;
+import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.lists.GeneList;
@@ -123,6 +137,11 @@ public class SessionWriter {
                 globalElement.setAttribute(SessionAttribute.GROUP_TRACKS_BY.getText(), groupBy);
             }
 
+            int nextAutoscaleGroup = session.getNextAutoscaleGroup();
+            if(nextAutoscaleGroup > 1) {
+                globalElement.setAttribute(SessionAttribute.NEXT_AUTOSCALE_GROUP.getText(), String.valueOf(nextAutoscaleGroup));
+            }
+
             if (session.isRemoveEmptyPanels()) {
                 globalElement.setAttribute("removeEmptyTracks", "true");
             }
@@ -300,7 +319,12 @@ public class SessionWriter {
                     Element dataFileElement = document.createElement(SessionElement.RESOURCE.getText());
 
                     //REQUIRED ATTRIBUTES - Cannot be null
-                    String relativePath = FileUtils.getRelativePath(outputFile.getAbsolutePath(), resourceLocator.getPath());
+
+                    boolean useRelative = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SESSION_RELATIVE_PATH);
+
+                    String relativePath = useRelative ?
+                            FileUtils.getRelativePath(outputFile.getAbsolutePath(), resourceLocator.getPath()) :
+                            resourceLocator.getPath();
 
                     dataFileElement.setAttribute(SessionAttribute.PATH.getText(), relativePath);
 
@@ -324,6 +348,9 @@ public class SessionWriter {
                     if (resourceLocator.getType() != null) {
                         dataFileElement.setAttribute(SessionAttribute.TYPE.getText(), resourceLocator.getType());
                     }
+                    if (resourceLocator.getIndexPath() != null) {
+                        dataFileElement.setAttribute(SessionAttribute.INDEX.getText(), resourceLocator.getIndexPath());
+                    }
                     if (resourceLocator.getCoverage() != null) {
                         dataFileElement.setAttribute(SessionAttribute.COVERAGE.getText(), resourceLocator.getCoverage());
                     }
@@ -383,18 +410,19 @@ public class SessionWriter {
     /**
      * Attempt to marshall the {@code track} into {@code trackParent} as it's
      * own class, if that fails, try the superclass, and so on up
+     *
      * @param m
      * @param track
      * @param trackParent
      * @throws javax.xml.bind.JAXBException
      */
-    private static void marshalTrack(Marshaller m, Track track, Node trackParent, Class marshalClass) throws JAXBException{
+    private static void marshalTrack(Marshaller m, Track track, Node trackParent, Class marshalClass) throws JAXBException {
 
-        if(marshalClass == null || marshalClass.equals(Object.class)){
+        if (marshalClass == null || marshalClass.equals(Object.class)) {
             throw new JAXBException(track.getClass() + " and none of its superclasses are known");
         }
 
-        if(AbstractTrack.knownUnknownTrackClasses.contains(marshalClass)){
+        if (AbstractTrack.knownUnknownTrackClasses.contains(marshalClass)) {
             marshalTrack(m, track, trackParent, marshalClass.getSuperclass());
             return;
         }
@@ -413,15 +441,16 @@ public class SessionWriter {
     /**
      * Because we are using JAXB piecewise, and also because JAXB can't handle
      * interfaces, we marshal certain track children here
+     *
      * @param m
      * @param track
      * @param trackElement
      */
-    private void marshalTrackChildren(Marshaller m, Track track, Element trackElement) throws JAXBException{
-        if(track instanceof FeatureTrack){
+    private void marshalTrackChildren(Marshaller m, Track track, Element trackElement) throws JAXBException {
+        if (track instanceof FeatureTrack) {
             FeatureTrack featureTrack = (FeatureTrack) track;
             featureTrack.marshalSource(m, trackElement);
-        }else if(track instanceof DataSourceTrack){
+        } else if (track instanceof DataSourceTrack) {
             DataSourceTrack dataSourceTrack = (DataSourceTrack) track;
             dataSourceTrack.marshalSource(m, trackElement);
         }
