@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -27,6 +41,8 @@ import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeDescriptor;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.feature.tribble.CodecFactory;
+import org.broad.igv.feature.tribble.GFFCodec;
+import org.broad.igv.feature.tribble.IGVBEDCodec;
 import org.broad.igv.sam.reader.AlignmentIndexer;
 import org.broad.igv.tdf.TDFUtils;
 import org.broad.igv.tools.converters.BamToBed;
@@ -43,11 +59,12 @@ import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.converters.DensitiesToBedGraph;
 import org.broad.igv.variant.util.VCFtoBed;
-import org.broad.tribble.FeatureCodec;
-import org.broad.tribble.TribbleException;
-import org.broad.tribble.index.Index;
-import org.broad.tribble.index.IndexFactory;
-import org.broad.tribble.util.LittleEndianOutputStream;
+import htsjdk.tribble.Feature;
+import htsjdk.tribble.FeatureCodec;
+import htsjdk.tribble.TribbleException;
+import htsjdk.tribble.index.Index;
+import htsjdk.tribble.index.IndexFactory;
+import htsjdk.tribble.util.LittleEndianOutputStream;
 
 import java.io.*;
 import java.util.*;
@@ -59,6 +76,10 @@ import java.util.*;
  */
 public class IgvTools {
 
+    public static final String CMD_WIGTOBED = "wigtobed";
+    public static final String CMD_VCFTOBED = "vcftobed";
+    public static final String CMD_DENSITIESTOBEDGRAPH = "densitiestobedgraph";
+    public static final String CMD_GEN_GENOME_LIST = "genGenomeList";
     static private Logger log = Logger.getLogger(IgvTools.class);
 
     static final String CMD_TILE = "tile";
@@ -71,6 +92,8 @@ public class IgvTools {
     static final String CMD_GUI = "gui";
     static final String CMD_HELP = "help";
     static final String CMD_BAMTOBED = "bamtobed";
+    static final String CMD_TDFTOBEDGRAPH = "tdftobedgraph";
+    static final String CMD_CONTACTS = "contacts";
 
     /**
      * Stream for writing messages to the user, which we
@@ -309,19 +332,7 @@ public class IgvTools {
                 validateArgsLength(nonOptionArgs, 4, basic_syntax);
                 int maxZoomValue = (Integer) parser.getOptionValue(maxZoomOption, MAX_ZOOM);
                 String ofile = nonOptionArgs[2];
-
-                //Output will be written to stdout instead of file,
-                //need to redirect user messages
-                if(ofile.equals(STDOUT_FILE_STR)){
-                    userMessageWriter = System.err;
-
-                    ConsoleAppender appender = (ConsoleAppender) Logger.getRootLogger().getAppender(CONSOLE_APPENDER_NAME);
-                    appender.setTarget(ConsoleAppender.SYSTEM_ERR);
-                    appender.activateOptions();
-
-                    //See log4j.properties file
-                    Logger.getRootLogger().removeAppender("stdout");
-                }
+                setWriteToStdOout(ofile);
 
                 String genomeId = nonOptionArgs[3];
 
@@ -382,6 +393,11 @@ public class IgvTools {
                 validateArgsLength(nonOptionArgs, 3, "Error in syntax. Expected: " + command + " [options] inputfile outputdir");
                 String outputDirectory = nonOptionArgs[2];
                 GFFParser.splitFileByType(ifile, outputDirectory);
+            } else if(command.equals("gfftobed")){
+                validateArgsLength(nonOptionArgs, 3, "Error in syntax. Expected: " + command + " inputfile outputfile");
+                String ofile = nonOptionArgs[2];
+                setWriteToStdOout(ofile);
+                GFFToBed(ifile, ofile);
             } else if (command.toLowerCase().equals("gcttoigv")) {
                 validateArgsLength(nonOptionArgs, 4, basic_syntax + " genomeId");
                 String ofile = nonOptionArgs[2];
@@ -396,11 +412,11 @@ public class IgvTools {
                 }
                 String probeFile = (String) parser.getOptionValue(probeFileOption, PROBE_FILE);
                 doGCTtoIGV(typeString, ifile, new File(ofile), probeFile, maxRecords, tmpDirName, genome);
-            } else if (command.toLowerCase().equals("tdftobedgraph")) {
+            } else if (command.toLowerCase().equals(CMD_TDFTOBEDGRAPH)) {
                 validateArgsLength(nonOptionArgs, 3, basic_syntax);
                 String ofile = nonOptionArgs[2];
                 TDFUtils.tdfToBedgraph(ifile, ofile);
-            } else if (command.equals("wigtobed")) {
+            } else if (command.equals(CMD_WIGTOBED)) {
                 validateArgsLength(nonOptionArgs, 2, "Error in syntax. Expected: " + command + " [options] inputfile");
                 String inputFile = nonOptionArgs[1];
                 float hetThreshold = 0.17f;
@@ -412,14 +428,14 @@ public class IgvTools {
                     homThreshold = Float.parseFloat(nonOptionArgs[3]);
                 }
                 WigToBed.run(inputFile, hetThreshold, homThreshold);
-            } else if (command.equals("vcftobed")) {
+            } else if (command.equals(CMD_VCFTOBED)) {
                 validateArgsLength(nonOptionArgs, 3, basic_syntax);
                 String inputFile = nonOptionArgs[1];
                 String outputFile = nonOptionArgs[2];
                 VCFtoBed.convert(inputFile, outputFile);
-            } else if (command.equals("sumwigs")) {
+            } else if (command.equals(CMD_SUMWIGS())) {
                 sumWigs(nonOptionArgs[1], nonOptionArgs[2]);
-            } else if (command.equals("densitiestobedgraph")) {
+            } else if (command.equals(CMD_DENSITIESTOBEDGRAPH)) {
                 validateArgsLength(nonOptionArgs, 3, "Error in syntax. Expected: " + command + " [options] inputdir outputdir");
                 File inputDir = new File(nonOptionArgs[1]);
                 File outputDir = new File(nonOptionArgs[2]);
@@ -434,13 +450,17 @@ public class IgvTools {
                 String ofile = nonOptionArgs[2];
                 Boolean pairOption = (Boolean) parser.getOptionValue(pairedCoverageOpt, false);
                 BamToBed.convert(new File(ifile), new File(ofile), pairOption);
-            } else if (command.equalsIgnoreCase("genGenomeList")) {
+            } else if (command.equalsIgnoreCase(CMD_GEN_GENOME_LIST)) {
                 //Generate a genomes.txt list file based on a directory
                 //TODO Probably a better place for this. Users won't generally use it
                 File inDir = new File(ifile);
                 GenomeManager manager = GenomeManager.getInstance();
                 manager.generateGenomeList(inDir, nonOptionArgs[2], nonOptionArgs[3]);
-            } else {
+            } else if(command.equalsIgnoreCase(CMD_CONTACTS)) {
+                PairedUtils.extractInteractions(ifile, nonOptionArgs[2], Integer.parseInt(nonOptionArgs[3]));
+            }
+
+            else {
                 throw new PreprocessingException("Unknown command: " + argv[EXT_FACTOR]);
             }
         } catch (IOException e) {
@@ -448,6 +468,73 @@ public class IgvTools {
         }
     }
 
+    private String CMD_SUMWIGS() {
+        return "sumwigs";
+    }
+
+    private void GFFToBed(String ifile, String ofile) throws FileNotFoundException{
+        IGVBEDCodec outCodec = new IGVBEDCodec();
+        GFFParser parser = new GFFParser();
+        GFFCodec codec = null;
+        try {
+            codec = (GFFCodec) CodecFactory.getCodec(ifile, null);
+        } catch (Exception e) {
+            throw new IllegalArgumentException("Input file is not recognized as a GFF");
+        }
+        BufferedReader reader = null;
+        PrintStream outStream = System.out;
+        if(!ofile.equals(STDOUT_FILE_STR)){
+            outStream = new PrintStream(new FileOutputStream(ofile));
+        }
+        try {
+            reader = ParsingUtils.openBufferedReader(ifile);
+            List<Feature> features = parser.loadFeatures(reader, null, codec);
+            for (Feature feat : features) {
+                String encoded = outCodec.encode(feat);
+                outStream.print(encoded);
+                outStream.print('\n');
+            }
+        } catch (IOException e) {
+            log.error(e.getMessage(), e);
+        } finally {
+            if (reader != null){
+                try {
+                    reader.close();
+                } catch (IOException e) {
+                    log.error(e.getMessage(), e);
+                }
+            }
+            if (outStream != null) {
+                outStream.flush();
+                outStream.close();
+            }
+        }
+    }
+
+    /**
+     * if ofile.equals(STDOUT_FILE_STR), write output to stdout. This also means redirecting log statements
+     * to someplace other than stdout, we use stderr
+     * @param ofile
+     * @return Whether output will be written to stdout
+     */
+    private boolean setWriteToStdOout(String ofile) {
+        //Output will be written to stdout instead of file,
+        //need to redirect user messages
+        if(ofile.equals(STDOUT_FILE_STR)){
+
+            userMessageWriter = System.err;
+
+            ConsoleAppender appender = (ConsoleAppender) Logger.getRootLogger().getAppender(CONSOLE_APPENDER_NAME);
+            appender.setTarget(ConsoleAppender.SYSTEM_ERR);
+            appender.activateOptions();
+
+            //See log4j.properties file
+            Logger.getRootLogger().removeAppender("stdout");
+            return true;
+        }
+        return false;
+    }
+
 
     private CmdLineParser initParser(String command) {
         command = command.toLowerCase();
@@ -1010,7 +1097,7 @@ public class IgvTools {
         //TODO Prevents loading genome again if loading from path.
         //May or may not want this, for now we just use it for testing
         if (Globals.isTesting() && genomeFile.getAbsolutePath().endsWith(".genome")) {
-            GenomeDescriptor genomeDescriptor = genomeManager.parseGenomeArchiveFile(genomeFile);
+            GenomeDescriptor genomeDescriptor = GenomeManager.parseGenomeArchiveFile(genomeFile);
             if (genome != null && genomeDescriptor.getId().equals(genome.getId())) {
                 return genome;
             }
