@@ -1,13 +1,28 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.track;
 
 //~--- non-JDK imports --------------------------------------------------------
@@ -33,7 +48,7 @@ import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.UIUtilities;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.Utilities;
-import org.broad.tribble.Feature;
+import htsjdk.tribble.Feature;
 import org.w3c.dom.Node;
 
 import javax.xml.bind.JAXBException;
@@ -49,7 +64,7 @@ import java.util.List;
  */
 @XmlType(factoryClass = IGVSessionReader.class, factoryMethod = "getNextTrack")
 @XmlAccessorType(XmlAccessType.NONE)
-@XmlSeeAlso({CoverageTrack.class, AlignmentTrack.class, DataSourceTrack.class, GWASTrack.class, FeatureTrack.class})
+@XmlSeeAlso({CoverageTrack.class, AlignmentTrack.class, DataSourceTrack.class, GWASTrack.class, FeatureTrack.class, MergedTracks.class})
 public abstract class AbstractTrack implements Track {
 
     private static Logger log = Logger.getLogger(AbstractTrack.class);
@@ -149,7 +164,7 @@ public abstract class AbstractTrack implements Track {
     protected Integer height = -1;
 
     @XmlElement(name = "DataRange")
-    private DataRange dataRange;
+    protected DataRange dataRange;
 
     @SubtlyImportant
     private AbstractTrack() {
@@ -236,7 +251,7 @@ public abstract class AbstractTrack implements Track {
     }
 
     @Override
-    public void preload(RenderContext context) {
+    public void load(RenderContext context) {
         // No-op, to be overriden by subclasses
     }
 
@@ -335,6 +350,10 @@ public abstract class AbstractTrack implements Track {
         return resourceLocator;
     }
 
+    public Collection<ResourceLocator> getResourceLocators() {
+        return Arrays.asList(getResourceLocator());
+    }
+
     /**
      * Add an attribute to this track and register the key with the attribute panel.
      * <p/>
@@ -350,6 +369,12 @@ public abstract class AbstractTrack implements Track {
         AttributeManager.getInstance().addAttribute(getSample(), name, value);
     }
 
+    public void removeAttribute(String name) {
+        String key = name.toUpperCase();
+        attributes.remove(key);
+        AttributeManager.getInstance().removeAttribute(getSample(), name);
+    }
+
 
     /**
      * Return the attribute value.  Attribute lookup occurs in the following order, if all fail null is returned.
@@ -589,15 +614,11 @@ public abstract class AbstractTrack implements Track {
         // Do nothing
     }
 
-    public boolean isAutoScale() {
-        return autoScale;
-    }
-
+    @Override
     public void setAutoScale(boolean autoScale) {
         this.autoScale = autoScale;
     }
 
-
     /**
      * Set some properties of this track,  usually from a "track line" specification.
      * <p/>
@@ -785,9 +806,9 @@ public abstract class AbstractTrack implements Track {
      *
      * @param node
      */
-    public void restorePersistentState(Node node) throws JAXBException {
+    public void restorePersistentState(Node node, int version) throws JAXBException {
         Map<String, String> attributes = Utilities.getAttributes(node);
-        restorePersistentState(attributes);
+        restorePersistentState(attributes, version);
     }
 
     /**
@@ -798,7 +819,7 @@ public abstract class AbstractTrack implements Track {
      * @param attributes
      * @see #getPersistentState
      */
-    public void restorePersistentState(Map<String, String> attributes) {
+    public void restorePersistentState(Map<String, String> attributes, int version) {
 
         String displayName = attributes.get(IGVSessionReader.SessionAttribute.DISPLAY_NAME.getText());
         String name = attributes.get(IGVSessionReader.SessionAttribute.NAME.getText());
@@ -809,14 +830,20 @@ public abstract class AbstractTrack implements Track {
             setName(displayName);
         }
 
+        if(attributes.containsKey("visible")) {
+            this.setVisible(Boolean.parseBoolean(attributes.get("visible")));
+        }
+
         // Set DataRange -- legacy (pre V3 sessions)
-        String scale = attributes.get(IGVSessionReader.SessionAttribute.SCALE.getText());
-        if (scale != null) {
-            String[] axis = scale.split(",");
-            float minimum = Float.parseFloat(axis[0]);
-            float baseline = Float.parseFloat(axis[1]);
-            float maximum = Float.parseFloat(axis[2]);
-            setDataRange(new DataRange(minimum, baseline, maximum));
+        if(version <= 3){
+            String scale = attributes.get(IGVSessionReader.SessionAttribute.SCALE.getText());
+            if (scale != null) {
+                String[] axis = scale.split(",");
+                float minimum = Float.parseFloat(axis[0]);
+                float baseline = Float.parseFloat(axis[1]);
+                float maximum = Float.parseFloat(axis[2]);
+                setDataRange(new DataRange(minimum, baseline, maximum));
+            }
         }
 
     }
