@@ -1,19 +1,26 @@
 /*
- * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
+ * The MIT License (MIT)
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
- * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
- * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
- * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
- * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
- * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
- * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
- * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
- * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
- * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -33,11 +40,14 @@ import org.broad.igv.renderer.MonocolorScale;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.color.ColorPalette;
 import org.broad.igv.ui.color.ColorTable;
-import org.broad.igv.ui.color.PaletteColorTable;
 import org.broad.igv.ui.color.ColorUtilities;
+import org.broad.igv.ui.color.PaletteColorTable;
 import org.broad.igv.ui.util.MessageUtils;
-import org.broad.igv.util.*;
-import org.broad.tribble.readers.AsciiLineReader;
+import org.broad.igv.util.FileUtils;
+import org.broad.igv.util.ParsingUtils;
+import org.broad.igv.util.ResourceLocator;
+import org.broad.igv.util.Utilities;
+import htsjdk.tribble.readers.AsciiLineReader;
 
 import java.awt.*;
 import java.beans.PropertyChangeEvent;
@@ -52,6 +62,9 @@ import java.util.List;
  */
 public class AttributeManager {
 
+    public static final String GROUP_AUTOSCALE = "AUTOSCALE GROUP";
+    public static List<String> defaultTrackAttributes = Arrays.asList(Globals.TRACK_NAME_ATTRIBUTE,
+            Globals.TRACK_DATA_FILE_ATTRIBUTE, Globals.TRACK_DATA_TYPE_ATTRIBUTE);
     private static Logger log = Logger.getLogger(AttributeManager.class);
 
     private static AttributeManager singleton;
@@ -163,7 +176,7 @@ public class AttributeManager {
     /**
      * Return true if the associated column contains all numeric values
      */
-    boolean isNumeric(String attributeName) {
+    public boolean isNumeric(String attributeName) {
         String key = attributeName.toUpperCase();
         ColumnMetaData metaData = columnMetaData.get(key);
         return metaData != null && metaData.isNumeric();
@@ -183,7 +196,9 @@ public class AttributeManager {
             Collections.emptyList();
         }
         final Set<String> hiddenAttributes = IGV.getInstance().getSession().getHiddenAttributes();
-        if (hiddenAttributes != null) visibleAttributes.removeAll(hiddenAttributes);
+        if (hiddenAttributes != null) {
+            visibleAttributes.removeAll(hiddenAttributes);
+        }
 
         return visibleAttributes;
     }
@@ -238,6 +253,15 @@ public class AttributeManager {
         updateMetaData(key, attributeValue);
     }
 
+    public void removeAttribute(String rowId, String attributeName) {
+
+        Map attributes = attributeMap.get(rowId);
+        if (attributes != null) {
+            attributes.remove(attributeName.toUpperCase());
+        }
+
+    }
+
     private void addAttributeName(String name) {
         String key = name.toUpperCase();
         if (!attributeNames.containsKey(key) && !name.startsWith("#")) {
@@ -277,12 +301,11 @@ public class AttributeManager {
      */
     public static boolean isSampleInfoFile(ResourceLocator locator) throws IOException {
 
-
         if (!FileUtils.isTabDelimited(locator, 2)) {
             return false;
         }
 
-        // If the file is "too large"  ask user
+        // If the file is too large, ask user
         // TODO -- ftp test
         final int oneMB = 1000000;
         long fileLength = ParsingUtils.getContentLength(locator.getPath());
@@ -290,8 +313,6 @@ public class AttributeManager {
             return MessageUtils.confirm("<html>Cannot determine file type of: " + locator.getPath() +
                     "<br>Is this a sample information file?");
         }
-
-
         return true;
     }
 
