@@ -1,18 +1,34 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.track;
 
 import com.google.common.eventbus.Subscribe;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
+import org.broad.igv.PreferenceManager;
 import org.broad.igv.cli_plugin.PluginFeatureSource;
 import org.broad.igv.cli_plugin.PluginSource;
 import org.broad.igv.feature.*;
@@ -30,8 +46,8 @@ import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.*;
 import org.broad.igv.variant.VariantTrack;
-import org.broad.tribble.Feature;
-import org.broad.tribble.TribbleException;
+import htsjdk.tribble.Feature;
+import htsjdk.tribble.TribbleException;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
@@ -119,11 +135,16 @@ public class FeatureTrack extends AbstractTrack {
     private static final String PLUGIN_SOURCE = "PluginSource";
     private static final String SEQUENCE_MATCH_SOURCE = "SequenceMatchSource";
 
+    private static Object loadLock = new Object();
+
+    //Force this track to load data synchronously.
+    //With this set to false, it chooses depending on the source
+    private boolean forceLoadSync = false;
 
     // TODO -- there are WAY too many constructors for this class
 
     /**
-     * Construct with no feature source.  Currently this is only used for the SpliceJunctionFinderTrack subclass.
+     * Construct with no feature source.  Currently this is only used for the SpliceJunctionTrack subclass.
      *
      * @param id
      * @param name
@@ -197,8 +218,15 @@ public class FeatureTrack extends AbstractTrack {
         setColor(Color.blue.darker());
 
         coverageRenderer = new BarChartRenderer();
-        if (source.getFeatureWindowSize() > 0) {
-            visibilityWindow = source.getFeatureWindowSize();
+
+        int sourceFeatureWindowSize = source.getFeatureWindowSize();
+        if (sourceFeatureWindowSize > 0) {  // Only apply a default if the feature source supports visibility window.
+            int defVisibilityWindow = PreferenceManager.getInstance().getAsInt(PreferenceManager.DEFAULT_VISIBILITY_WINDOW);
+            if (defVisibilityWindow > 0) {
+                setVisibilityWindow(defVisibilityWindow * 1000);
+            } else {
+                visibilityWindow = sourceFeatureWindowSize;
+            }
         }
 
         this.renderer = path != null && path.endsWith("junctions.bed") ?
@@ -306,10 +334,10 @@ public class FeatureTrack extends AbstractTrack {
     public float getRegionScore(String chr, int start, int end, int zoom, RegionScoreType scoreType, String frameName) {
 
         try {
-            if (scoreType == RegionScoreType.MUTATION_COUNT && this.getTrackType() == TrackType.MUTATION) {
-                Iterator<Feature> features = source.getFeatures(chr, start, end);
-                int count = 0;
-                if (features != null) {
+            Iterator<Feature> features = source.getFeatures(chr, start, end);
+            if (features != null) {
+                if (scoreType == RegionScoreType.MUTATION_COUNT && this.getTrackType() == TrackType.MUTATION) {
+                    int count = 0;
                     while (features.hasNext()) {
                         Feature f = features.next();
                         if (f.getStart() > end) {
@@ -319,8 +347,29 @@ public class FeatureTrack extends AbstractTrack {
                             count++;
                         }
                     }
+
+                    return count;
+                } else if (scoreType == RegionScoreType.SCORE) {
+                    // Average score of features in region.  Note: Should the score be weighted by genomic size?
+                    float regionScore = 0;
+                    int nValues = 0;
+                    while (features.hasNext()) {
+                        Feature f = features.next();
+                        if (f instanceof IGVFeature) {
+                            if ((f.getEnd() >= start) && (f.getStart() <= end)) {
+                                float value = ((IGVFeature) f).getScore();
+                                regionScore += value;
+                                nValues++;
+                            }
+                        }
+                    }
+                    if (nValues == 0) {
+                        // No scores in interval
+                        return -Float.MAX_VALUE;
+                    } else {
+                        return regionScore / nValues;
+                    }
                 }
-                return count;
             }
         } catch (IOException e) {
             log.error("Error counting features.", e);
@@ -474,7 +523,7 @@ public class FeatureTrack extends AbstractTrack {
     }
 
     /**
-     * Knowing the feature row, figure out which feature is at position position. If not expanded,
+     * Knowing the feature row, figure out which feature is at {@code position}. If not expanded,
      * featureRow is ignored
      *
      * @param position
@@ -490,7 +539,9 @@ public class FeatureTrack extends AbstractTrack {
             return null;
         }
 
-        int nLevels = packedFeatures.getRowCount();
+        //If features are stacked we look at only the row.
+        //If they are collapsed on top of each other, we get all features in all rows
+        int nLevels = areFeaturesStacked() ? packedFeatures.getRowCount() : 1;
         List<IGVFeature> possFeatures = null;
         if ((nLevels > 1) && (featureRow < nLevels)) {
             possFeatures = packedFeatures.getRows().get(featureRow).getFeatures();
@@ -608,7 +659,7 @@ public class FeatureTrack extends AbstractTrack {
     }
 
     @Override
-    public void preload(RenderContext context) {
+    public void load(RenderContext context) {
         ReferenceFrame frame = context.getReferenceFrame();
         PackedFeatures packedFeatures = packedFeaturesMap.get(frame.getName());
         String chr = context.getChr();
@@ -659,27 +710,32 @@ public class FeatureTrack extends AbstractTrack {
     }
 
     protected boolean isShowFeatures(RenderContext context) {
-        double windowSize = context.getEndLocation() - context.getOrigin();
-        int vw = getVisibilityWindow();
-        return (vw <= 0 && !context.getChr().equals(Globals.CHR_ALL) ||
-                windowSize <= vw && !context.getChr().equals(Globals.CHR_ALL));
+
+        if (context.getChr().equals(Globals.CHR_ALL)) {
+            return false;
+        } else {
+            double windowSize = context.getEndLocation() - context.getOrigin();
+            int vw = getVisibilityWindow();
+            return (vw <= 0 || windowSize <= vw);
+        }
     }
 
     protected void renderCoverage(RenderContext context, Rectangle inputRect) {
-        if (source == null) {
-            return;
-        }
 
-        List<LocusScore> scores = source.getCoverageScores(context.getChr(), (int) context.getOrigin(),
-                (int) context.getEndLocation(), context.getZoom());
+        final String chr = context.getChr();
+
+        List<LocusScore> scores = (source != null && chr.equals(Globals.CHR_ALL)) ?
+                source.getCoverageScores(chr, (int) context.getOrigin(),
+                        (int) context.getEndLocation(), context.getZoom()) :
+                null;
+
         if (scores == null) {
             Graphics2D g = context.getGraphic2DForColor(Color.gray);
             Rectangle textRect = new Rectangle(inputRect);
 
             // Keep text near the top of the track rectangle
             textRect.height = Math.min(inputRect.height, 20);
-            String message = context.getChr().equals(Globals.CHR_ALL) ? "Zoom in to see features." :
-                    "Zoom in to see features, or right-click to increase Feature Visibility Window.";
+            String message = getZoomInMessage(chr);
             GraphicUtils.drawCenteredText(message, textRect, g);
 
         } else {
@@ -693,6 +749,11 @@ public class FeatureTrack extends AbstractTrack {
         }
     }
 
+    protected String getZoomInMessage(String chr) {
+        return chr.equals(Globals.CHR_ALL) ? "Zoom in to see features." :
+                        "Zoom in to see features, or right-click to increase Feature Visibility Window.";
+    }
+
     private float getMaxEstimate(List<LocusScore> scores) {
         float max = 0;
         int n = Math.min(200, scores.size());
@@ -721,10 +782,10 @@ public class FeatureTrack extends AbstractTrack {
 
         //Attempt to load the relevant data. Note that there is no guarantee
         //the data will be loaded once preload exits, as loading may be asynchronous
-        preload(context);
+        load(context);
         PackedFeatures packedFeatures = packedFeaturesMap.get(context.getReferenceFrame().getName());
 
-        if (packedFeatures == null || !packedFeatures.containsInterval(context.getChr(), (int) context.getOrigin(), (int) context.getEndLocation() + 1)) {
+        if (packedFeatures == null || !packedFeatures.overlapsInterval(context.getChr(), (int) context.getOrigin(), (int) context.getEndLocation() + 1)) {
             return;
         }
 
@@ -798,51 +859,52 @@ public class FeatureTrack extends AbstractTrack {
      * @param start
      * @param end
      */
-    protected synchronized void loadFeatures(final String chr, final int start, final int end, final RenderContext context) {
+    protected void loadFeatures(final String chr, final int start, final int end, final RenderContext context) {
 
-        // TODO -- improve or remove the need for this test.  We know that FeatureCollectionSource has all the data
-        // in memory, and can by run synchronously
-        boolean aSync = !(source instanceof FeatureCollectionSource);
+        boolean aSync = !forceLoadSync && !(source instanceof FeatureCollectionSource);
 
 
         NamedRunnable runnable = new NamedRunnable() {
             public void run() {
                 try {
                     featuresLoading = true;
-                    if (log.isTraceEnabled()) {
-                        log.trace(String.format("Loading features: %s:%d-%d", chr, start, end));
-                    }
+
+                    synchronized (loadLock) {
+                        if (log.isTraceEnabled()) {
+                            log.trace(String.format("Loading features: %s:%d-%d", chr, start, end));
+                        }
 
 
-                    int delta = (end - start) / 2;
-                    int expandedStart = start - delta;
-                    int expandedEnd = end + delta;
+                        int delta = (end - start) / 2;
+                        int expandedStart = start - delta;
+                        int expandedEnd = end + delta;
 
-                    //Make sure we are only querying within the chromosome
-                    //we allow for somewhat pathological cases of start
-                    //being negative and end being outside, but
-                    //only if directly queried. Our expansion should not
-                    //set start < 0 or end > chromosomeLength
-                    if (start >= 0) {
-                        expandedStart = Math.max(0, expandedStart);
-                    }
+                        //Make sure we are only querying within the chromosome
+                        //we allow for somewhat pathological cases of start
+                        //being negative and end being outside, but
+                        //only if directly queried. Our expansion should not
+                        //set start < 0 or end > chromosomeLength
+                        if (start >= 0) {
+                            expandedStart = Math.max(0, expandedStart);
+                        }
 
 
-                    Genome genome = GenomeManager.getInstance().getCurrentGenome();
-                    if (genome != null) {
-                        Chromosome c = genome.getChromosome(chr);
-                        if (c != null && end < c.getLength()) expandedEnd = Math.min(c.getLength(), expandedEnd);
-                    }
+                        Genome genome = GenomeManager.getInstance().getCurrentGenome();
+                        if (genome != null) {
+                            Chromosome c = genome.getChromosome(chr);
+                            if (c != null && end < c.getLength()) expandedEnd = Math.min(c.getLength(), expandedEnd);
+                        }
 
-                    Iterator<Feature> iter = source.getFeatures(chr, expandedStart, expandedEnd);
-                    if (iter == null) {
-                        PackedFeatures pf = new PackedFeatures(chr, expandedStart, expandedEnd);
-                        packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
-                    } else {
-                        //dhmay putting a switch in for different packing behavior in splice junction tracks.
-                        //This should probably be switched somewhere else, but that would require a big refactor.
-                        PackedFeatures pf = new PackedFeatures(chr, expandedStart, expandedEnd, iter, getName());
-                        packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
+                        Iterator<Feature> iter = source.getFeatures(chr, expandedStart, expandedEnd);
+                        if (iter == null) {
+                            PackedFeatures pf = new PackedFeatures(chr, expandedStart, expandedEnd);
+                            packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
+                        } else {
+                            //dhmay putting a switch in for different packing behavior in splice junction tracks.
+                            //This should probably be switched somewhere else, but that would require a big refactor.
+                            PackedFeatures pf = new PackedFeatures(chr, expandedStart, expandedEnd, iter, getName());
+                            packedFeaturesMap.put(context.getReferenceFrame().getName(), pf);
+                        }
                     }
 
                     //Now that features are loaded, we may need to repaint
@@ -875,6 +937,10 @@ public class FeatureTrack extends AbstractTrack {
 
     }
 
+    public void setForceLoadSync(boolean forceLoadSync) {
+        this.forceLoadSync = forceLoadSync;
+    }
+
     /**
      * Called after features are finished loading, which can be asynchronous
      *
@@ -970,8 +1036,8 @@ public class FeatureTrack extends AbstractTrack {
     }
 
     @Override
-    public void restorePersistentState(Node node) throws JAXBException {
-        super.restorePersistentState(node);
+    public void restorePersistentState(Node node, int version) throws JAXBException {
+        super.restorePersistentState(node, version);
         if (node.hasChildNodes()) {
             NodeList childNodes = node.getChildNodes();
             for (int ii = 0; ii < childNodes.getLength(); ii++) {
@@ -1044,5 +1110,37 @@ public class FeatureTrack extends AbstractTrack {
             ((PluginSource) source).updateTrackReferences(allTracks);
         }
     }
+
+    /**
+     * Features are packed upon loading, effectively a cache.
+     * This clears that cache. Used to force a refresh
+     *
+     * @api
+     */
+    public void clearPackedFeatures() {
+        this.packedFeaturesMap.clear();
+    }
+
+    /**
+     * Return currently loaded features.  Used to export features to a file.
+     *
+     * @param frame
+     * @return
+     */
+    public List<Feature> getVisibleFeatures(ReferenceFrame frame) {
+        PackedFeatures packedFeatures = packedFeaturesMap.get(frame.getName());
+        return (packedFeatures == null) ? Collections.emptyList() : packedFeatures.getFeatures();
+
+
+    }
+
+    /**
+     * Return "track" line information for exporting features to a file.  Default is null, subclasses may override.
+     *
+     * @return
+     */
+    public String getExportTrackLine() {
+        return null;
+    }
 }
 
