@@ -1,20 +1,33 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.track;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.feature.*;
-import org.broad.igv.feature.genome.Genome;
-import org.broad.tribble.Feature;
+import htsjdk.tribble.Feature;
 
 import java.io.IOException;
 import java.util.*;
@@ -23,10 +36,11 @@ import java.util.*;
  * User: jacob
  * Date: 2012-Jun-22
  */
-public class GFFFeatureSource extends TribbleFeatureSource {
+public class GFFFeatureSource implements org.broad.igv.track.FeatureSource {
 
     private static Logger log = Logger.getLogger(GFFFeatureSource.class);
 
+    private FeatureSource wrappedSource;
 
     public static boolean isGFF(String path) {
         String lowpath = path.toLowerCase();
@@ -41,21 +55,35 @@ public class GFFFeatureSource extends TribbleFeatureSource {
         return lowpath.endsWith("gff3") || lowpath.endsWith("gvf") || lowpath.endsWith("gff") || lowpath.endsWith("gtf");
     }
 
-    public GFFFeatureSource(String path, Genome genome) throws IOException {
-        super(path, genome);
-        this.isVCF = false;
+    public GFFFeatureSource(FeatureSource wrappedSource) throws IOException {
+        this.wrappedSource = wrappedSource;
     }
 
     @Override
     public Iterator<Feature> getFeatures(String chr, int start, int end) throws IOException {
 
-        Iterator<Feature> rawIter = super.getFeatures(chr, start, end);
+        Iterator<Feature> rawIter = wrappedSource.getFeatures(chr, start, end);
         GFFCombiner combiner = (new GFFCombiner()).addFeatures(rawIter);
 
 
         return new WrappedIterator(combiner.combineFeatures().iterator());
     }
 
+    @Override
+    public List<LocusScore> getCoverageScores(String chr, int start, int end, int zoom) {
+        return wrappedSource.getCoverageScores(chr, start, end, zoom);
+    }
+
+    @Override
+    public int getFeatureWindowSize() {
+        return wrappedSource.getFeatureWindowSize();
+    }
+
+    @Override
+    public void setFeatureWindowSize(int size) {
+        wrappedSource.setFeatureWindowSize(size);
+    }
+
     /**
      * The GFF spec is available at http://www.sequenceontology.org/gff3.shtml
      * <p/>
@@ -133,12 +161,15 @@ public class GFFFeatureSource extends TribbleFeatureSource {
                 for (String parentId : parentIds) {
                     BasicFeature parent = gffFeatures.get(parentId);
                     if (parent == null) {
-                        igvFeatures.add(gffExon);
-                    } else {
-                        final Exon exon = new Exon(gffExon);
-                        exon.setNonCoding(!SequenceOntology.isCoding(gffExon.getType()));
-                        parent.addExon(exon);
+                        parent = createParent(gffExon);
+                        parent.setIdentifier(parentId);
+                        parent.setName(parentId);
+                        gffFeatures.put(parentId, parent);
                     }
+                    final Exon exon = new Exon(gffExon);
+                    exon.setNonCoding(!SequenceOntology.isCoding(gffExon.getType()));
+                    parent.addExon(exon);
+
                 }
             }
 
@@ -147,10 +178,13 @@ public class GFFFeatureSource extends TribbleFeatureSource {
                 for (String parentId : utr.getParentIds()) {
                     BasicFeature parent = gffFeatures.get(parentId);
                     if (parent == null) {
-                        igvFeatures.add(utr);
-                    } else {
-                        parent.addUTRorCDS(utr);
+                        parent = createParent(utr);
+                        parent.setIdentifier(parentId);
+                        parent.setName(parentId);
+                        gffFeatures.put(parentId, parent);
                     }
+                    parent.addUTRorCDS(utr);
+
                 }
             }
 
@@ -163,9 +197,10 @@ public class GFFFeatureSource extends TribbleFeatureSource {
                 if (parent == null) {
                     // Create a "dummy" transcript for the orphaned cds records
                     parent = new BasicFeature(gffCdsCltn.chr, gffCdsCltn.start, gffCdsCltn.end, gffCdsCltn.strand);
-                    igvFeatures.add(parent);
+                    parent.setIdentifier(parentId);
+                    parent.setName(parentId);
+                    gffFeatures.put(parentId, parent);
                 }
-
                 // Now add the cds objects.  There are 2 conventions in use for describing the coding section of mRNAs
                 // (1) All cds records for the same isoform get the same id.  CDS objects with different ids then
                 // imply different isoforms.  In IGV we need to create a parent object for each.  (2) each CDS has
@@ -219,6 +254,12 @@ public class GFFFeatureSource extends TribbleFeatureSource {
 
         }
 
+        private BasicFeature createParent(BasicFeature gffExon) {
+            BasicFeature parent;
+            parent = new BasicFeature(gffExon.getChr(), gffExon.getStart(), gffExon.getEnd(), gffExon.getStrand());
+            return parent;
+        }
+
 
         private static BasicFeature copyForCDS(BasicFeature bf) {
 
