@@ -1,16 +1,31 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.track;
 
+import htsjdk.tribble.Feature;
 import org.apache.log4j.Logger;
 import org.broad.igv.PreferenceManager;
 import org.broad.igv.bbfile.BBFileReader;
@@ -35,6 +50,7 @@ import org.broad.igv.exceptions.DataLoadException;
 import org.broad.igv.feature.CachingFeatureSource;
 import org.broad.igv.feature.GisticFileParser;
 import org.broad.igv.feature.MutationTrackLoader;
+import org.broad.igv.feature.bionano.SMAPParser;
 import org.broad.igv.feature.dranger.DRangerParser;
 import org.broad.igv.feature.genome.*;
 import org.broad.igv.feature.tribble.CodecFactory;
@@ -86,19 +102,6 @@ public class TrackLoader {
 
     private static Collection<? extends Class> NOLogExceptions = Arrays.asList(TribbleIndexNotFoundException.class);
 
-    /**
-     * Calls {@linkplain TrackLoader#load(org.broad.igv.util.ResourceLocator, org.broad.igv.feature.genome.Genome)}
-     * with genome from IGV instance (if not null).
-     *
-     * @param locator
-     * @param igv
-     * @return
-     */
-    public List<Track> load(ResourceLocator locator, IGV igv) throws DataLoadException {
-        Genome genome = igv != null ? GenomeManager.getInstance().getCurrentGenome() : null;
-        return load(locator, genome);
-    }
-
     /**
      * Switches on various attributes of locator (mainly locator path extension and whether the locator is indexed)
      * to call the appropriate loading method.
@@ -206,6 +209,8 @@ public class TrackLoader {
             } else if (typeString.endsWith(".list")) {
                 // This should be deprecated
                 loadListFile(locator, newTracks, genome);
+            } else if (typeString.endsWith(".smap")) {
+                loadSMAPFile(locator, newTracks, genome);
             } else if (handler != null) {
                 //Custom loader specified
                 log.info(String.format("Loading %s with %s", path, handler));
@@ -251,6 +256,14 @@ public class TrackLoader {
 
     }
 
+    private void loadSMAPFile(ResourceLocator locator, List<Track> newTracks, Genome genome) throws IOException {
+
+        List<Feature> features = SMAPParser.parseFeatures(locator, genome);
+        FeatureCollectionSource src = new FeatureCollectionSource(features, genome);
+        FeatureTrack track = new FeatureTrack(locator, locator.getName(), src);
+        newTracks.add(track);
+    }
+
     private boolean forceNotTribble(String typeString) {
         List<String> nonTribble = Arrays.asList("fpkm_tracking", "exp_diff", "_exp.diff");
         for (String s : nonTribble) {
@@ -386,7 +399,7 @@ public class TrackLoader {
                     t.setHeight(15);
                 }
             }
-            if (locator.getPath().contains(".narrowPeak") || locator.getPath().contains(".broadPeak")) {
+            if (locator.getPath().contains(".narrowPeak") || locator.getPath().contains(".broadPeak") || locator.getPath().contains(".gappedPeak")) {
                 t.setUseScore(true);
             }
             newTracks.add(t);
@@ -881,26 +894,28 @@ public class TrackLoader {
 
             AlignmentTrack alignmentTrack = new AlignmentTrack(locator, dataManager, genome);    // parser.loadTrack(locator, dsName);
             alignmentTrack.setName(dsName);
-
+            alignmentTrack.setVisible(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_ALIGNMENT_TRACK));
 
             // Create coverage track
-            CoverageTrack covTrack = new CoverageTrack(locator, alignmentTrack.getName() + " Coverage", genome);
+            CoverageTrack covTrack = new CoverageTrack(locator, dsName + " Coverage", alignmentTrack, genome);
             covTrack.setVisible(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_COV_TRACK));
             newTracks.add(covTrack);
-            alignmentTrack.setCoverageTrack(covTrack);
             covTrack.setDataManager(dataManager);
             dataManager.setCoverageTrack(covTrack);
 
+            alignmentTrack.setCoverageTrack(covTrack);
+
             // Search for precalculated coverage data
             // Skip for GA4GH & SU2C resources
             if (!(Ga4ghAPIHelper.RESOURCE_TYPE.equals(locator.getType()) ||
-                   locator.getPath().contains("dataformat=.bam") ||
+                    locator.getPath().contains("dataformat=.bam") ||
                     OAuthUtils.isGoogleCloud(locator.getPath()))) {
 
                 String covPath = locator.getCoverage();
                 if (covPath == null) {
+                    boolean bypassFileAutoDiscovery = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.BYPASS_FILE_AUTO_DISCOVERY);
                     String path = locator.getPath();
-                    if (!path.contains("/query.cgi?")) {
+                    if (!bypassFileAutoDiscovery && !path.contains("/query.cgi?")) {
                         covPath = path + ".tdf";
                     }
 
@@ -910,7 +925,7 @@ public class TrackLoader {
                         log.debug("Loading TDF for coverage: " + covPath);
                         try {
                             TDFReader reader = TDFReader.getReader(covPath);
-                            TDFDataSource ds = new TDFDataSource(reader, 0, alignmentTrack.getName() + " coverage", genome);
+                            TDFDataSource ds = new TDFDataSource(reader, 0, dsName + " coverage", genome);
                             covTrack.setDataSource(ds);
                         } catch (Exception e) {
                             log.error("Error loading coverage TDF file", e);
@@ -921,18 +936,19 @@ public class TrackLoader {
             }
 
             boolean showSpliceJunctionTrack = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_JUNCTION_TRACK);
-            if (showSpliceJunctionTrack) {
-                SpliceJunctionFinderTrack spliceJunctionTrack = new SpliceJunctionFinderTrack(locator,
-                        alignmentTrack.getName() + " Junctions", dataManager, SpliceJunctionFinderTrack.StrandOption.BOTH);
-                spliceJunctionTrack.setHeight(60);
 
-                spliceJunctionTrack.setVisible(showSpliceJunctionTrack);
-                newTracks.add(spliceJunctionTrack);
-                alignmentTrack.setSpliceJunctionTrack(spliceJunctionTrack);
-            }
-            log.debug("Alignment track loaded");
+            SpliceJunctionTrack spliceJunctionTrack = new SpliceJunctionTrack(locator,
+                    dsName + " Junctions", dataManager, alignmentTrack, SpliceJunctionTrack.StrandOption.BOTH);
+            spliceJunctionTrack.setHeight(60);
+            spliceJunctionTrack.setVisible(showSpliceJunctionTrack);
+            newTracks.add(spliceJunctionTrack);
+
+            alignmentTrack.setSpliceJunctionTrack(spliceJunctionTrack);
+
             newTracks.add(alignmentTrack);
 
+            log.debug("Alignment track loaded");
+
         } catch (IndexNotFoundException e) {
             MessageUtils.showMessage("<html>Could not find the index file for  <br><br>&nbsp;&nbsp;" + e.getSamFile() +
                     "<br><br>Note: The index file can be created using igvtools and must be in the same directory as the .sam file.");
