@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -42,11 +56,11 @@ import org.broad.igv.lists.GeneList;
 import org.broad.igv.lists.Preloader;
 import org.broad.igv.peaks.PeakCommandBar;
 import org.broad.igv.sam.AlignmentTrack;
-import org.broad.igv.sam.reader.BAMHttpReader;
 import org.broad.igv.session.IGVSessionReader;
 import org.broad.igv.session.Session;
 import org.broad.igv.session.SessionReader;
 import org.broad.igv.session.UCSCSessionReader;
+import org.broad.igv.session.IndexAwareSessionReader;
 import org.broad.igv.track.*;
 import org.broad.igv.ui.dnd.GhostGlassPane;
 import org.broad.igv.ui.event.*;
@@ -575,12 +589,12 @@ public class IGV {
                         GenomeListItem newItem = new GenomeListItem(oldItem.getDisplayableName(), newLocation.getAbsolutePath(), oldItem.getId());
                         //Checking to see if it has a downloaded sequence might seem redundant,
                         //but if the user cancels a download we want to use the oldItem
-                        if(newItem.hasDownloadedSequence()){
+                        if (newItem.hasDownloadedSequence()) {
                             selectedValues = Arrays.asList(newItem);
                         }
                     }
 
-                    if(selectedValues.size() > 0){
+                    if (selectedValues.size() > 0) {
                         GenomeManager.getInstance().addGenomeItems(selectedValues, false);
                         getContentPane().getCommandBar().refreshGenomeListComboBox();
                         selectGenomeFromList(selectedValues.get(0).getId());
@@ -956,6 +970,7 @@ public class IGV {
 
 
     final public void doRefresh() {
+
         contentPane.getMainPanel().revalidate();
         mainFrame.repaint();
         //getContentPane().repaint();
@@ -1019,7 +1034,7 @@ public class IGV {
             token = WaitCursorManager.showWaitCursor();
             contentPane.getStatusBar().setMessage("Exporting image: " + defaultFile.getAbsolutePath());
             String msg = createSnapshotNonInteractive(target, file, false);
-            if(msg != null && msg.toLowerCase().startsWith("error")){
+            if (msg != null && msg.toLowerCase().startsWith("error")) {
                 MessageUtils.showMessage(msg);
             }
         } catch (IOException e) {
@@ -1405,9 +1420,10 @@ public class IGV {
             inputStream = new BufferedInputStream(ParsingUtils.openInputStreamGZ(new ResourceLocator(sessionPath)));
 
             boolean isUCSC = sessionPath.endsWith(".session") || sessionPath.endsWith(".session.txt");
+            boolean isIndexAware = sessionPath.endsWith(".idxsession") || sessionPath.endsWith(".idxsession.txt");
             final SessionReader sessionReader = isUCSC ?
                     new UCSCSessionReader(this) :
-                    new IGVSessionReader(this);
+                    (isIndexAware ? new IndexAwareSessionReader(this) : new IGVSessionReader(this));
 
             sessionReader.loadSession(inputStream, session, sessionPath);
 
@@ -1743,7 +1759,8 @@ public class IGV {
     public List<Track> load(ResourceLocator locator) throws DataLoadException {
 
         TrackLoader loader = new TrackLoader();
-        List<Track> newTracks = loader.load(locator, this);
+        Genome genome = GenomeManager.getInstance().getCurrentGenome();
+        List<Track> newTracks = loader.load(locator, genome);
         if (newTracks.size() > 0) {
             for (Track track : newTracks) {
                 String fn = locator.getPath();
@@ -1758,6 +1775,7 @@ public class IGV {
                 track.setAttributeValue(Globals.TRACK_DATA_FILE_ATTRIBUTE, fn);
                 track.setAttributeValue(Globals.TRACK_DATA_TYPE_ATTRIBUTE, track.getTrackType().toString());
 
+                // If the track listens for group events add it to the listener list
                 if (track instanceof TrackGroupEventListener) {
                     addGroupEventListener((TrackGroupEventListener) track);
                 }
@@ -2366,6 +2384,15 @@ public class IGV {
         }
     }
 
+    public void notifyAlignmentTrackEvent(Object source, AlignmentTrackEvent.Type type, boolean value) {
+        AlignmentTrackEvent e = new AlignmentTrackEvent(source, type, value);
+        for (SoftReference<AlignmentTrackEventListener> ref : alignmentTrackListeners) {
+            AlignmentTrackEventListener l = ref.get();
+            l.onAlignmentTrackEvent(e);
+        }
+    }
+
+
     public void notifyAlignmentTrackEvent(Object source, AlignmentTrackEvent.Type type) {
         AlignmentTrackEvent e = new AlignmentTrackEvent(source, type);
         for (SoftReference<AlignmentTrackEventListener> ref : alignmentTrackListeners) {
@@ -2519,7 +2546,7 @@ public class IGV {
                         }
 
                         //Set index file, iff one was passed
-                        if(indexFiles != null && i < indexFiles.length) {
+                        if (indexFiles != null && i < indexFiles.length) {
                             String idxP = indexFiles[i];
                             if (HttpUtils.isURL(idxP) && !FileUtils.isRemote(idxP)) {
                                 idxP = StringUtils.decodeURL(idxP);
@@ -2530,7 +2557,7 @@ public class IGV {
                         }
 
                         //Set coverage file, iff one was passed
-                        if(coverageFiles != null && i < coverageFiles.length) {
+                        if (coverageFiles != null && i < coverageFiles.length) {
                             String covP = coverageFiles[i];
                             if (HttpUtils.isURL(covP) && !FileUtils.isRemote(covP)) {
                                 covP = StringUtils.decodeURL(covP);
@@ -2548,6 +2575,7 @@ public class IGV {
 
                 indefMonitor.stop();
                 closeWindow(progressDialog2);
+
             }
 
             session.recordHistory();
@@ -2572,6 +2600,10 @@ public class IGV {
                     }
                     if (runningBatch) {
                         LongRunningTask.submit(new BatchRunner(igvArgs.getBatchFile()));
+                    } else {
+//                        if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SHOW_LOS)) {
+//                            (new LOSDialog(mainFrame)).setVisible(true);
+//                        }
                     }
 
                 }
@@ -2616,7 +2648,7 @@ public class IGV {
             }
             pluginClassNames.addAll(Arrays.asList(PreferenceManager.getInstance().getIGVPluginList()));
             for (String classname : pluginClassNames) {
-                if(classname.startsWith("#")) continue;
+                if (classname.startsWith("#")) continue;
                 try {
                     Class clazz = Class.forName(classname);
                     IGVPlugin plugin = (IGVPlugin) clazz.newInstance();
