@@ -1,25 +1,34 @@
-/**
- * Copyright (c) 2010-2011 by Fred Hutchinson Cancer Research Center.  All Rights Reserved.
-
- * This software is licensed under the terms of the GNU Lesser General
- * Public License (LGPL), Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
-
- * THE SOFTWARE IS PROVIDED "AS IS." FRED HUTCHINSON CANCER RESEARCH CENTER MAKES NO
- * REPRESENTATIONS OR WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED,
- * INCLUDING, WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
- * PARTICULAR PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS,
- * WHETHER OR NOT DISCOVERABLE.  IN NO EVENT SHALL FRED HUTCHINSON CANCER RESEARCH
- * CENTER OR ITS TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR
- * ANY DAMAGES OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR
- * CONSEQUENTIAL DAMAGES, ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS,
- * REGARDLESS OF  WHETHER FRED HUTCHINSON CANCER RESEARCH CENTER SHALL BE ADVISED,
- * SHALL HAVE OTHER REASON TO KNOW, OR IN FACT SHALL KNOW OF THE POSSIBILITY OF THE
- * FOREGOING.
+/*
+ * The MIT License (MIT)
+ *
+ * Copyright (c) 2007-2015 Fred Hutchinson Cancer Research Center and Broad Institute
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
+
 package org.broad.igv.ui.panel;
 
 import com.google.common.eventbus.Subscribe;
 import org.apache.log4j.Logger;
+import org.broad.igv.feature.Range;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.lists.GeneList;
@@ -331,14 +340,13 @@ public class RegionNavigatorDialog extends JDialog implements Observer{
         if (descObject != null)
             region.setDescription(descObject.toString());
 
-        //stored values are 0-based, viewed values are 1-based.  Check for negative number just in case
+        //stored values are 0-based end-exclusive, viewed values are 1-based end-inclusive.  Check for negative number just in case
         int storeStartValue =
                 Math.max(0, (Integer) regionTableModel.getValueAt(rowIdx, TABLE_COLINDEX_START) - 1);
         region.setStart(storeStartValue);
 
-        //stored values are 0-based, viewed values are 1-based.  Check for negative number just in case
         int storeEndValue =
-                Math.max(0, (Integer) regionTableModel.getValueAt(rowIdx, TABLE_COLINDEX_END) - 1);
+                Math.max(0, (Integer) regionTableModel.getValueAt(rowIdx, TABLE_COLINDEX_END));
         region.setEnd(storeEndValue);
     }
 
@@ -468,16 +476,14 @@ public class RegionNavigatorDialog extends JDialog implements Observer{
         setTitle("Regions of Interest");
         setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
         addWindowListener(new WindowAdapter() {
-            @Override
-            public void windowClosed(WindowEvent e) {
-                thisWindowClosed(e);
-            }
-
             @Override
             public void windowActivated(WindowEvent e) {
                 thisWindowActivated(e);
             }
-
+            @Override
+            public void windowClosed(WindowEvent e) {
+                thisWindowClosed(e);
+            }
             @Override
             public void windowDeactivated(WindowEvent e) {
                 thisWindowDeactivated(e);
@@ -525,25 +531,23 @@ public class RegionNavigatorDialog extends JDialog implements Observer{
 
                     //---- regionTable ----
                     regionTable.setModel(new DefaultTableModel(
-                            new Object[][]{
-                                    {null, null, null, null},
-                            },
-                            new String[]{
-                                    "Chr", "Start", "End", "Description"
-                            }
+                        new Object[][] {
+                            {null, null, null, null},
+                        },
+                        new String[] {
+                            "Chr", "Start", "End", "Description"
+                        }
                     ) {
-                        Class<?>[] columnTypes = new Class<?>[]{
-                                String.class, Integer.class, Integer.class, Object.class
+                        Class<?>[] columnTypes = new Class<?>[] {
+                            String.class, Integer.class, Integer.class, Object.class
                         };
-                        boolean[] columnEditable = new boolean[]{
-                                false, true, true, true
+                        boolean[] columnEditable = new boolean[] {
+                            false, true, true, true
                         };
-
                         @Override
                         public Class<?> getColumnClass(int columnIndex) {
                             return columnTypes[columnIndex];
                         }
-
                         @Override
                         public boolean isCellEditable(int rowIndex, int columnIndex) {
                             return columnEditable[columnIndex];
@@ -689,7 +693,7 @@ public class RegionNavigatorDialog extends JDialog implements Observer{
                         "Regions cannot be created in the All Chromosomes view.",
                         "Error", JOptionPane.INFORMATION_MESSAGE);
             } else {
-                ReferenceFrame.Range r = FrameManager.getDefaultFrame().getCurrentRange();
+                Range r = FrameManager.getDefaultFrame().getCurrentRange();
                 RegionOfInterest newRegion = new RegionOfInterest(r.getChr(), r.getStart(), r.getEnd(), "");
                 IGV.getInstance().getSession().addRegionOfInterestWithNoListeners(newRegion);
             }
@@ -736,7 +740,7 @@ public class RegionNavigatorDialog extends JDialog implements Observer{
                 List<RegionOfInterest> selectedRegions = getSelectedRegions(selectedRows);
 
                 // Create an "on-the-fly" gene list
-                // TODO -- this is ineffecient (converting regions -> strings then back again)
+                // TODO -- this is inefficient (converting regions -> strings then back again)
                 List<String> loci = new ArrayList<String>(selectedRegions.size());
                 if (checkBoxZoomWhenNav.isSelected() || selectedRegions.size() >= 2 || FrameManager.isGeneListMode()) {
                     for (RegionOfInterest roi : selectedRegions) {
@@ -745,10 +749,15 @@ public class RegionNavigatorDialog extends JDialog implements Observer{
                 } else {
                     //Need to preserve current zoom, iff checkbox not selected and only choosing 1
                     RegionOfInterest roi = selectedRegions.get(0);
-                    ReferenceFrame.Range range = FrameManager.getDefaultFrame().getCurrentRange();
+                    Range range = FrameManager.getDefaultFrame().getCurrentRange();
                     int length = range.getLength();
                     int start = roi.getCenter() - length / 2;
                     int end = start + length;
+                    //Shift so we don't go below 0
+                    if(start < 0){
+                        end += Math.abs(start);
+                        start = 0;
+                    }
                     loci.add(new RegionOfInterest(roi.getChr(), start, end, roi.getDescription()).getLocusString());
                 }
                 GeneList geneList = new GeneList("Regions of Interest", loci, false);
