@@ -1,20 +1,28 @@
 /*
- * Copyright (c) 2007-2011 by The Broad Institute of MIT and Harvard.  All Rights Reserved.
+ * The MIT License (MIT)
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * THE SOFTWARE IS PROVIDED "AS IS." THE BROAD AND MIT MAKE NO REPRESENTATIONS OR
- * WARRANTES OF ANY KIND CONCERNING THE SOFTWARE, EXPRESS OR IMPLIED, INCLUDING,
- * WITHOUT LIMITATION, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
- * PURPOSE, NONINFRINGEMENT, OR THE ABSENCE OF LATENT OR OTHER DEFECTS, WHETHER
- * OR NOT DISCOVERABLE.  IN NO EVENT SHALL THE BROAD OR MIT, OR THEIR RESPECTIVE
- * TRUSTEES, DIRECTORS, OFFICERS, EMPLOYEES, AND AFFILIATES BE LIABLE FOR ANY DAMAGES
- * OF ANY KIND, INCLUDING, WITHOUT LIMITATION, INCIDENTAL OR CONSEQUENTIAL DAMAGES,
- * ECONOMIC DAMAGES OR INJURY TO PROPERTY AND LOST PROFITS, REGARDLESS OF WHETHER
- * THE BROAD OR MIT SHALL BE ADVISED, SHALL HAVE OTHER REASON TO KNOW, OR IN FACT
- * SHALL KNOW OF THE POSSIBILITY OF THE FOREGOING.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 /*
  * TrackPanel.java
  *
@@ -43,7 +51,9 @@ import org.jdesktop.layout.GroupLayout;
 import javax.swing.*;
 import javax.swing.event.MouseInputAdapter;
 import java.awt.*;
-import java.awt.event.*;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.MouseEvent;
 import java.awt.image.BufferedImage;
 import java.util.*;
 import java.util.List;
@@ -182,7 +192,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
                                 Graphics2D graphics2D, int regionX, int regionY) {
 
 
-        List<Track> tmp = new ArrayList(group.getTracks());
+        List<Track> tmp = new ArrayList(group.getVisibleTracks());
         final Color backgroundColor = PreferenceManager.getInstance().getAsColor(PreferenceManager.BACKGROUND_COLOR);
         graphics2D.setBackground(backgroundColor);
         graphics2D.clearRect(visibleRect.x, visibleRect.y, visibleRect.width, visibleRect.height);
@@ -349,10 +359,6 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
          */
         public void mousePressed(MouseEvent e) {
 
-            if (log.isDebugEnabled()) {
-                log.debug("Enter mousePressed");
-            }
-
             dragStart = e.getPoint();
 
             requestFocus();
@@ -412,8 +418,8 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
 
         public void mouseReleased(MouseEvent e) {
 
-            if (log.isDebugEnabled()) {
-                log.debug("Enter mouseReleased");
+            if (log.isTraceEnabled()) {
+                log.trace("Enter mouseReleased");
             }
 
             if (isDragging) {
@@ -657,7 +663,7 @@ public class TrackNamePanel extends TrackPanelComponent implements Paintable {
     private void selectGroup(TrackGroup group) {
         selectedGroup = group;
         if (selectedGroup != null) {
-            for (Track t : selectedGroup.getTracks()) {
+            for (Track t : selectedGroup.getVisibleTracks()) {
                 t.setSelected(true);
             }
         }
