@@ -1,19 +1,34 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.util;
 
+import org.broad.igv.util.ftp.FTPUtils;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.ui.util.MessageUtils;
 
 import java.io.*;
 import java.net.MalformedURLException;
@@ -35,52 +50,16 @@ public class FileUtils {
     final static String[] igvJnlpPrefixes = {"igv", "ichip", "29mammals", "hic"};
 
 
-    /**
-     * Replace all occurences of str1 with str2 in all files in inputDirectory.  Write the modified files
-     * to outputDirectory.  Note: assumption is all files are text.
-     *
-     * @param inputDirectory
-     * @param outputDirectory
-     * @param str1
-     * @param str2
-     */
-    public static void searchAndReplace(File inputDirectory, File outputDirectory, String str1, String str2)
-            throws IOException {
-
-        for (File in : inputDirectory.listFiles()) {
-            if (!in.isDirectory() && !in.isHidden()) {
-
-                File of = new File(outputDirectory, in.getName());
-                BufferedReader reader = null;
-                PrintWriter pw = null;
-
-                try {
-                    reader = new BufferedReader(new FileReader(in));
-                    pw = new PrintWriter(new BufferedWriter(new FileWriter(of)));
-                    String nextLine;
-                    while ((nextLine = reader.readLine()) != null) {
-                        nextLine = nextLine.replaceAll(str1, str2);
-                        pw.println(nextLine);
-                    }
-                } finally {
-                    reader.close();
-                    pw.close();
-
-                }
-
-
-            }
-        }
-
-    }
 
     public static boolean resourceExists(String path) {
         try {
-            boolean remoteFile = isRemote(path);
-            return (!remoteFile && (new File(path).exists())) ||
-                    (remoteFile && HttpUtils.getInstance().resourceAvailable(new URL(path)));
+            if (isRemote(path)) {
+                return HttpUtils.getInstance().resourceAvailable(new URL(path));
+            } else {
+                return (new File(path)).exists();
+            }
         } catch (IOException e) {
-            log.error("Malformed URL: " + path, e);
+            log.error("Error checking existence of: " + path, e);
             return false;
         }
     }
@@ -239,60 +218,9 @@ public class FileUtils {
     }
 
 
-    public static void fixEOL(String ifile, String ofile) {
-        BufferedReader br = null;
-        PrintWriter pw = null;
-        try {
-            br = new BufferedReader(new FileReader(ifile));
-            pw = new PrintWriter(new FileWriter(ofile));
-            String nextLine;
-            while ((nextLine = br.readLine()) != null) {
-                pw.println(nextLine);
-            }
-
-            br.close();
-            pw.close();
-
-        } catch (Exception e) {
-            e.printStackTrace();
-        } finally {
-
-        }
-    }
-
     /**
-     * Test to see if a file is ascii by sampling the first few bytes.  Not perfect (obviously) but usually works
-     */
-    public static boolean isAscii(ResourceLocator loc) throws IOException {
-
-        InputStream in = null;
-        CharsetDecoder d = Charset.forName("US-ASCII").newDecoder();
-        try {
-            in = ParsingUtils.openInputStreamGZ(loc);
-
-            byte[] bytes = new byte[1024]; //do a peek
-            int nBytes = in.read(bytes);
-
-            while (nBytes > 0) {
-                for (int i = 0; i < nBytes; i++) {
-                    int j = (int) bytes[i];
-                    if (j < 1 || j > 127) {
-                        return false;
-                    }
-                }
-                nBytes = in.read(bytes);
-            }
-            return true;
-        } finally {
-            if (in != null) {
-                in.close();
-            }
-        }
-    }
-
-
-    /**
-     * Test to see if the ascii file is tab delimited.  Samples first 5 non-comment (lines starting with #) lines
+     * Test to see if the first comment line (first line not starting with #) is tab-delimited with the
+     * given number of minimum columns.  Limit the test to the first 1,000 lines.
      */
     public static boolean isTabDelimited(ResourceLocator loc, int minColumnCount) throws IOException {
 
@@ -302,7 +230,7 @@ public class FileUtils {
             reader = ParsingUtils.openBufferedReader(loc.getPath());
             int nLinesTested = 0;
             String nextLine;
-            while ((nextLine = reader.readLine()) != null && nLinesTested < 5) {
+            while ((nextLine = reader.readLine()) != null && nLinesTested < 1000) {
                 if (nextLine.startsWith("#")) {
                     continue;
                 }
@@ -312,7 +240,7 @@ public class FileUtils {
                     return true;
                 }
             }
-            return nLinesTested > 1;
+            return false;
         } finally {
             if (reader != null) {
                 reader.close();
@@ -322,7 +250,7 @@ public class FileUtils {
 
 
     /**
-     * Create a file from an input stream.
+     * Copy a file from one location to another, using buffered writing
      *
      * @param inputFile
      * @param outputFile
@@ -331,8 +259,6 @@ public class FileUtils {
 
     public static void copyFile(File inputFile, File outputFile) throws IOException {
 
-        int totalSize = 0;
-
         OutputStream out = null;
         InputStream in = null;
         try {
@@ -342,12 +268,11 @@ public class FileUtils {
             int bytes_read;
             while ((bytes_read = in.read(buffer)) != -1) {
                 out.write(buffer, 0, bytes_read);
-                totalSize += bytes_read;
             }
 
         } catch (Exception e) {
             outputFile.delete();
-            MessageUtils.showMessage("<html>Error copying file: " + outputFile.getAbsoluteFile() +
+            throw new RuntimeException("<html>Error copying file: " + outputFile.getAbsoluteFile() +
                     "<br/>" + e.toString());
 
         } finally {
@@ -361,48 +286,6 @@ public class FileUtils {
         }
     }
 
-
-    public static void replaceStrings(File inputFile, File outputFile, Map<String, String> replace) throws IOException {
-
-        BufferedReader reader = null;
-        PrintWriter writer = null;
-
-        try {
-            reader = new BufferedReader(new FileReader(inputFile));
-            writer = new PrintWriter(new BufferedWriter(new FileWriter(outputFile)));
-            String nextLine;
-            while ((nextLine = reader.readLine()) != null) {
-                for (Map.Entry<String, String> entry : replace.entrySet()) {
-                    nextLine = nextLine.replace(entry.getKey(), entry.getValue());
-                }
-                writer.println(nextLine);
-            }
-
-        } finally {
-            reader.close();
-            writer.close();
-
-        }
-    }
-
-    /**
-     * Cleanup extra jnlp files.  This method is written specifcally for Mac OS.
-     */
-    public static void cleanupJnlpFiles() {
-
-        // Cleanup jnlp files
-        if (Globals.IS_MAC) {
-            File desktop = new File(System.getProperty("user.home") + "/Desktop");
-            if (desktop.exists() && desktop.isDirectory()) {
-                FileUtils.cleanup(desktop);
-            }
-            File downloads = new File(System.getProperty("user.home") + "/Downloads");
-            if (downloads.exists() && downloads.isDirectory()) {
-                FileUtils.cleanup(downloads);
-            }
-        }
-    }
-
     private static void cleanup(File dir) {
 
         if (dir.exists() && dir.isDirectory()) {
@@ -499,8 +382,13 @@ public class FileUtils {
         } else {
             File parent = new File(referencePath).getParentFile();
             File file = new File(parent, inputPath);
-            absolutePath = file.getAbsolutePath();
+            try {
+                absolutePath = file.getCanonicalPath();
+            } catch (IOException e) {
+                absolutePath = file.getAbsolutePath();
+            }
         }
+
         return absolutePath;
     }
 
@@ -529,6 +417,7 @@ public class FileUtils {
 
         String systemPath = System.getenv("PATH");
         if (systemPath == null) systemPath = System.getenv("path");
+        if (systemPath == null || File.pathSeparator == null) return executable;
 
         String[] pathDirs = systemPath.split(File.pathSeparator);
 
@@ -543,27 +432,35 @@ public class FileUtils {
         return fullPath;
     }
 
+
+
     /**
-     * Convert a list of ":" separated paths, relative to rootPath,
-     * into file URLs
+     * Return the length of the file, which might be remote.
      *
-     * @param libs
-     * @param rootPath
+     * @param file
      * @return
      */
-    public static URL[] getURLsFromString(String libs, String rootPath) {
-        String[] sLibs = libs.split(":");
-        List<URL> libURLList = new ArrayList<URL>(sLibs.length);
-        String pluginDir = (new File(rootPath)).getParent();
-        for (String s : sLibs) {
-            File fi = new File(pluginDir, s);
+    public static long getLength(String file) {
+
+        if (isRemote(file)) {
             try {
-                libURLList.add(new URL("file:" + fi.getAbsolutePath()));
-            } catch (MalformedURLException e) {
-                log.error("Error adding to libs: " + fi.getAbsolutePath());
-                log.error(e);
+                URL url = new URL(file);
+                if (file.startsWith("ftp://")) {
+                    return FTPUtils.getContentLength(url);
+                } else {
+                    return HttpUtils.getInstance().getContentLength(url);
+                }
+            } catch (Exception e) {
+                log.error("Error fetching content length for: " + file, e);
+                return -1;
+            }
+        } else {
+            File f = new File(file);
+            if (f.exists() && f.isFile()) {
+                return f.length();
+            } else {
+                return -1;
             }
         }
-        return libURLList.toArray(new URL[0]);
     }
-}
\ No newline at end of file
+}
