@@ -1,20 +1,33 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.util;
 
-//~--- non-JDK imports --------------------------------------------------------
-
-import net.sf.samtools.util.ftp.FTPClient;
-import net.sf.samtools.util.ftp.FTPReply;
-import net.sf.samtools.util.ftp.FTPUtils;
+import htsjdk.samtools.util.ftp.FTPClient;
+import htsjdk.samtools.util.ftp.FTPReply;
+import org.broad.igv.util.ftp.FTPUtils;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
 import org.broad.igv.renderer.*;
@@ -23,7 +36,7 @@ import org.broad.igv.track.TrackProperties;
 import org.broad.igv.track.WindowFunction;
 import org.broad.igv.ui.color.ColorUtilities;
 import org.broad.igv.ui.util.MessageUtils;
-import org.broad.tribble.readers.AsciiLineReader;
+import htsjdk.tribble.readers.AsciiLineReader;
 
 import java.awt.*;
 import java.io.*;
@@ -379,19 +392,29 @@ public class ParsingUtils {
                             boolean autoscale = value.equals("on");
                             trackProperties.setAutoScale(autoscale);
                         } else if (key.equals("maxheightpixels")) {
-                            // There should be 3 values per UCSC spec,  max:default:min.  In the past we have accepted
-                            // 2 values,  def:min,  so keep this for backwards compatibility.   IGV currently doesn't
-                            // have a "max height"   UPDATE -- apparently 1 value is also allowed!
-                            String[] maxDefMin = value.split(":");
-                            if (maxDefMin.length >= 2) {
-                                int defIDX = (maxDefMin.length == 2 ? 0 : 1);
-                                trackProperties.setHeight(Integer.parseInt(maxDefMin[defIDX].trim()));
-                                trackProperties.setMinHeight(Integer.parseInt(maxDefMin[defIDX + 1].trim()));
-                            } else {
-                                // Single value
-                                trackProperties.setHeight(Integer.parseInt(value));
+                            try {
+                                // There should be 3 values per UCSC spec,  max:default:min.  In the past we have accepted
+                                // 2 values,  def:min,  so keep this for backwards compatibility.   IGV currently doesn't
+                                // have a "max height"   UPDATE -- apparently 1 value is also allowed!
+                                String[] maxDefMin = value.split(":");
+                                if (maxDefMin.length >= 2) {
+                                    int defIDX = (maxDefMin.length == 2 ? 0 : 1);
+                                    trackProperties.setHeight(Integer.parseInt(maxDefMin[defIDX].trim()));
+                                    trackProperties.setMinHeight(Integer.parseInt(maxDefMin[defIDX + 1].trim()));
+                                } else {
+                                    // Single value
+                                    trackProperties.setHeight(Integer.parseInt(value));
+                                }
+                            } catch (NumberFormatException e) {
+                                log.error("height must be an integer: " + value);
                             }
-
+                        } else if ("height".equals(key)) {
+                            try {
+                                trackProperties.setHeight(Integer.parseInt(value));
+                            } catch (NumberFormatException e) {
+                                log.error("height must be an integer: " + value);
+                            }
+                            
                         } else if (key.equals("url")) {
                             trackProperties.setUrl(value);
                         } else if (key.equals("graphtype")) {
@@ -410,6 +433,8 @@ public class ParsingUtils {
                                 trackProperties.setRendererClass(SpliceJunctionRenderer.class);
                             } else if (value.equals("genotype")) {
                                 trackProperties.setRendererClass(GenotypeRenderer.class);
+                            } else if ("arc".equals(value)) {
+                                trackProperties.setRendererClass(ArcRenderer.class);
                             }
                         } else if (key.toLowerCase().equals("viewlimits")) {
                             String[] limits = value.split(":");
@@ -483,6 +508,10 @@ public class ParsingUtils {
                             trackProperties.setGenome(value);
                         } else if (key.equals("bigdataurl") || key.equals("dataurl")) {
                             trackProperties.setDataURL(value);
+                        } else if (key.equals("indexurl")) {
+                            trackProperties.setIndexURL(value);
+                        } else if (key.equals("coverageurl")) {
+                            trackProperties.setCoverageURL(value);
                         } else if (key.equals("meta")) {
                             trackProperties.setMetaData(value);
                         }
@@ -519,11 +548,6 @@ public class ParsingUtils {
      */
     public static String getIGVExtension(String path) {
 
-        // _sorted.txt is an old alignment format.
-        if (path.endsWith("_sorted.txt")) {
-            return "_sorted.txt";
-        }
-
         // String off gzip first
         if (path.endsWith(".gz")) path = path.substring(0, path.length() - 3);
 
