@@ -1,7 +1,7 @@
 /*
- * The MIT License
+ * The MIT License (MIT)
  *
- * Copyright (c) 2009 The Broad Institute
+ * Copyright (c) 2007-2015 Broad Institute
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -13,6 +13,7 @@
  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.
  *
+ *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
@@ -25,7 +26,8 @@
 package org.broad.igv.util.stream;
 
 import com.google.common.primitives.Ints;
-import net.sf.samtools.seekablestream.SeekableStream;
+import htsjdk.samtools.seekablestream.SeekableStream;
+import org.apache.log4j.Logger;
 
 import java.io.IOException;
 
@@ -33,17 +35,23 @@ import static java.lang.System.arraycopy;
 
 /**
  * A wrapper class to provide buffered read access to a SeekableStream.  Just wrapping such a stream with
- * a BufferedInputStream will not work as it does not support seeking.  In this implementation a
- * seek call is delegated to the wrapped stream, and the buffer reset.
+ * a BufferedInputStream will not work as it does not support seeking.  In this implementation,
+ * we attempt to reuse the buffer if there is overlap between the newly requested range and where
+ * the buffer contains data for.
  */
 public class IGVSeekableBufferedStream extends SeekableStream {
 
+    private static Logger log = Logger.getLogger(IGVSeekableBufferedStream.class);
+
     public static final int DEFAULT_BUFFER_SIZE = 512000;
 
     final private int maxBufferSize;
     final SeekableStream wrappedStream;
     long position;
-    long length;
+    /**
+     * Can't make the assumption that length is a valid value.
+     * May be -1, which means we don't know.
+     */
 
     int markpos;
     int marklimit;
@@ -56,7 +64,6 @@ public class IGVSeekableBufferedStream extends SeekableStream {
         this.maxBufferSize = bsize;
         this.wrappedStream = stream;
         this.position = 0;
-        this.length = wrappedStream.length();
         this.buffer = new byte[maxBufferSize];
         this.bufferStartPosition = -1;
         this.bufferSize = 0;
@@ -68,12 +75,15 @@ public class IGVSeekableBufferedStream extends SeekableStream {
     }
 
     public long length() {
-        return length;
+        return wrappedStream.length();
     }
 
     @Override
     public long skip(final long skipLength) throws IOException {
-        long actualSkip = Math.min(length - position - 1, skipLength);
+        long maxSkip = Long.MAX_VALUE;
+        long length = wrappedStream.length();
+        if (length >= 0) maxSkip = length - position - 1;
+        long actualSkip = Math.min(maxSkip, skipLength);
         position += actualSkip;
         return actualSkip;
     }
@@ -108,7 +118,8 @@ public class IGVSeekableBufferedStream extends SeekableStream {
     }
 
     public boolean eof() throws IOException {
-        return position >= wrappedStream.length();
+        long length = wrappedStream.length();
+        return length >= 0 && position >= length;
     }
 
     @Override
@@ -124,10 +135,11 @@ public class IGVSeekableBufferedStream extends SeekableStream {
     /**
      * Return true iff the buffer needs to be refilled for the given
      * amount of data requested
+     *
      * @param len Number of bytes from {@code position} one plans on reading
      * @return
      */
-    private boolean needFillBuffer(int len){
+    private boolean needFillBuffer(int len) {
         return bufferSize == 0 || position < bufferStartPosition || (position + len) > bufferStartPosition + bufferSize;
     }
 
@@ -144,17 +156,10 @@ public class IGVSeekableBufferedStream extends SeekableStream {
         return b;
     }
 
-    /**
-     * This method implements the general contract of the corresponding read method of the InputStream class.
-     * @param b   destination buffer;
-     * @param off offset at which to start storing bytes.
-     * @param len maximum number of bytes to read.
-     * @return the number of bytes read, or -1 if the end of the stream has been reached.
-     * @throws IOException
-     */
     public int read(final byte[] b, final int off, final int len) throws IOException {
 
-        if (position >= length) return -1;
+        long length = wrappedStream.length();
+        if (length >= 0 && position >= length) return -1;
 
         if (len > maxBufferSize) {
             // Buffering not useful here.  Don't bother trying to use any (possible) overlapping buffer contents
@@ -178,44 +183,74 @@ public class IGVSeekableBufferedStream extends SeekableStream {
 
     private void fillBuffer() throws IOException {
 
-        int n = 0;
-        long longLen = Math.min((long) maxBufferSize, (length - position));
+        long longRem = maxBufferSize;
+        long length = wrappedStream.length();
+
+        if (length >= 0) longRem = Math.min((long) maxBufferSize, length - position);
+
         //This shouldn't actually be necessary as long as maxBufferSize is
         //an int, but we leave it here to stress the fact that
         //we need to watch for overflow
-        int len = Ints.saturatedCast(longLen);
+        int bytesRemaining = Ints.saturatedCast(longRem);
+        //Number of bytes to skip at beginning when reading from stream later
+        int toSkip = 0;
+        //Number of bytes known to be stored in the buffer, which are valid
+        int tmpBufferSize = 0;
 
-        int offset = 0;
-//        long bufferEnd = bufferStartPosition + bufferSize;
-//        if(position + len > bufferStartPosition && position < bufferStartPosition) {
-//           // There is some overlap
-//            int sz = (int) (position + len - bufferStartPosition);
-//            arraycopy(buffer, bufferSize - sz, buffer, 0, sz);
-//
-//            n += sz;
-//            len -= sz;
-//        }
-//        else if(position + len > bufferEnd && position < bufferEnd) {
-//            int sz = (int) (bufferEnd - position);
-//            offset = sz;
-//            arraycopy(buffer, 0, buffer, bufferSize - sz, sz);
-//
-//            n += sz;
-//            len -= sz;
-//
-//        }
+        long bufferEnd = bufferStartPosition + bufferSize;
+        long requiredEnd = position + bytesRemaining;
 
-        if (len > 0) {
-            wrappedStream.seek(position + offset);
-            while (n < len) {
-                int count = wrappedStream.read(buffer, n, len - n);
-                if (count < 0) {
-                    break;  // EOF.  This should not be possible as len is capped above.
+        if (bufferStartPosition > position && bufferEnd < requiredEnd) {
+            // Buffer is in the middle of the required range, don't bother trying to reuse
+        } else {
+            if (position < bufferEnd && requiredEnd > bufferEnd) {
+                // Beginning of buffer data is useless, want to save
+                // some though
+                // Fill request:           xxxxxxxx...
+                // Buffer data:    xxxxxxxxxxxxx
+                int szOverlap = (int) (bufferEnd - position);
+                try {
+                    arraycopy(buffer, bufferSize - szOverlap, buffer, 0, szOverlap);
+                } catch (Exception e) {
+                    e.printStackTrace();
                 }
-                n += count;
+
+                //Skip the first bytes that we already had
+                toSkip = szOverlap;
+                tmpBufferSize += szOverlap;
+                bytesRemaining -= szOverlap;
+            } else if (position < bufferStartPosition && requiredEnd > bufferStartPosition && requiredEnd < bufferEnd) {
+                //Gap between position and buffer start, but some overlap
+                //We require that the buffer contain data all the way to the end,
+                //because dealing with the case of writing buffered data to the middle
+                //is too complicated and not likely to occur in practice. When it does,
+                //we just re-read everything.
+                // Fill request: xxxxxxxxxxxx...
+                // Buffer data:      xxxxxxxxxxx...
+                int szOverlap = (int) (requiredEnd - bufferStartPosition);
+                int destPos = (int) (bufferStartPosition - position);
+                arraycopy(buffer, 0, buffer, destPos, szOverlap);
+
+                //Don't skip any bytes, just trim from the number requested
+                bytesRemaining -= szOverlap;
+                tmpBufferSize += szOverlap;
+            }
+        }
+
+        if (bytesRemaining > 0) {
+            int curOffset = toSkip;
+            wrappedStream.seek(position + toSkip);
+            while (bytesRemaining > 0) {
+                int count = wrappedStream.read(buffer, curOffset, bytesRemaining);
+                if (count < 0) {
+                    break;  // EOF.
+                }
+                curOffset += count;
+                bytesRemaining -= count;
+                tmpBufferSize += count;
             }
             bufferStartPosition = position;
-            bufferSize = n;
+            bufferSize = tmpBufferSize;
         }
     }
 }
\ No newline at end of file
