@@ -1,20 +1,33 @@
 /*
- * Copyright (c) 2007-2013 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.util.stream;
 
 import htsjdk.samtools.seekablestream.SeekableStream;
 import org.apache.log4j.Logger;
-import htsjdk.tribble.util.URLHelper;
-import org.broad.igv.exceptions.HttpResponseException;
+import org.broad.igv.ui.util.Packable;
 import org.broad.igv.util.HttpUtils;
 
 import java.io.EOFException;
@@ -65,6 +78,26 @@ public class IGVSeekableHTTPStream extends SeekableStream {
 
     public int read(byte[] buffer, int offset, int len) throws IOException {
 
+        int attempts = 0;
+        while(attempts < 3) {
+            try {
+                return _read(buffer, offset, len);
+            } catch (java.net.SocketException e) {
+                if(attempts < 3) {
+                    attempts++;
+                    log.error("Socket exception. Trying again.", e);
+                }
+                else {
+                    throw e;
+                }
+            }
+        }
+
+        throw new RuntimeException("Reading " + url + " failed with unknown error.");  // Should be impossible to get here
+    }
+
+    public int _read(byte[] buffer, int offset, int len) throws IOException {
+
         String stats = "Offset=" + offset + ",len=" + len + ",buflen=" + buffer.length;
         if (offset < 0 || len < 0 || (offset + len) > buffer.length) {
             throw new IndexOutOfBoundsException(stats);
@@ -134,6 +167,7 @@ public class IGVSeekableHTTPStream extends SeekableStream {
     }
 
 
+
     public void close() throws IOException {
         // Nothing to do
     }
@@ -173,7 +207,6 @@ public class IGVSeekableHTTPStream extends SeekableStream {
     }
 
 
-
     /**
      * Add query parameters which should more properly be in Range header field
      * to query string
